import SQLite from "better-sqlite3";
import sqlite from "../../../utils/sqlite.js";
import mentions from "../../../utils/mentions.js";
import logging from "../../../utils/logging.js";
import common from "../../../utils/common.js";
import ban from "../../commands/moderation/ban.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    name: `ban`,
    aliases: [`b`],

    async execute(message, ourArguments, Discord, client)
    {
        const { sendDmOnBan, banAppealsLink } = common.getGuildConfig(message.guild.id);

        if (!common.canRunCommand(message, `BanMembers`))
            return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].noPermission }`);

        if (!ourArguments[0])
            return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].mentionUser }`);

        var id = ourArguments[0];
        if (id[0] === `<`)
            id = mentions.getUserFromMention(ourArguments[0]);

        const row = sql.prepare(`SELECT * FROM tempbanUsers WHERE guildId = ? AND userId = ?`).get(message.guild.id, id);

        if (ourArguments[1])
        { // args[1] can either be a duration or a reason
            const Time = ourArguments[1];
            var time = await common.getEpoch(Time, false);
            if (time === -1337)
            {
                time = -1337; // perma ban
                var reason = ourArguments.slice(1).join(` `);
                if (!reason || !ourArguments[1])
                    reason = `${ global.locale[global.findLocale(message.guild.id)].noReasonSpecified }`;
                reason = common.truncateString(reason, 256);
            }
            else
            {
                var reason = ourArguments.slice(2).join(` `);
                if (!reason || !ourArguments[2])
                    reason = `${ global.locale[global.findLocale(message.guild.id)].noReasonSpecified }`;
                reason = common.truncateString(reason, 256);

                if (row && row.time > 1)
                { // If they are already muted, and have a punishment, take their current mute time and add the new time to it.
                    time = Number.parseInt(row.time, 10) + time;
                    sql.prepare(`UPDATE tempbanUsers SET time = ?, moderatorId = ? WHERE guildId = ? AND userId = ?`).run(time, message.author.id, message.guild.id, id);
                }
                else if (row && row.time < 1)
                    return message.channel.send(`${ global.locale[global.findLocale(message.guild.id)].permBanned }`);
                else
                { // fresh temp ban
                    time += Date.now();
                    sql.prepare(`INSERT INTO tempbanUsers VALUES (?, ?, ?, ?, ?)`).run(`${ message.guild.id }_${ id }`, message.guild.id, id, time, message.author.id);
                }
            }
        }

        const authorTag = message.author.tag;

        var isSilent = false;
        if (reason.includes(`--silent`))
        {
            isSilent = true; // Do not send DM upon ban.
            reason = reason.replace(`--silent`, ``);
        }

        if (time > 0)
            var timeForMuteMeta = `${ global.locale[global.findLocale(message.guild.id)].for } ${ ourArguments[1] }`;
        else
            var timeForMuteMeta = `${ global.locale[global.findLocale(message.guild.id)].permanently }`;

        const guild = client.guilds.cache.get(message.guild.id);
        const member = await common.getGuildMember(client, message.guild.id, id);
        if (!member)
        {
            // prevent double banning
            let isBanned = true;
            await guild.bans.fetch(id).catch(() =>
            {
                isBanned = false;
            });
            if (isBanned && time < 0)
                return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].alreadyBanned }`);
            if (isBanned && time > 0)
                return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].banTimeUpdate.replaceAll(`%ourArguments%`, `${ ourArguments[1] }`) }`);

            // They aren't in the server, try anyways
            await message.guild.members.ban(id, { deleteMessageSeconds: 7 * 24 * 60 * 60, reason: `${ authorTag } | ${ reason }` }).then(async () =>
            {
                ban.sendBanEmbed(Discord, client, id, id, message.author.id, reason, message.guild.id, time);
                var newReason = `🔨 ${ reason }`;
                await sqlite.modifyPunishmentsProfile(client, id, message.author.id, message.guild.id, `bans`, 1, newReason, timeForMuteMeta);
            }).catch((error) =>
            {
                logging.error(error);
                message.channel.send(`${ global.locale[global.findLocale(message.guild.id)].mentionUser }`).then((message) =>
                {
                    setTimeout(() =>
                    {
                        message.delete();
                    }, 10_000);
                });
            });
            return; // we banned someone not in the server, so we're done here
        }

        if ((member.roles.highest.position >= message.member.roles.highest.position && guild.ownerId !== message.author.id) || !member.bannable)
            return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].couldntBanUser }`);

        if (sendDmOnBan && banAppealsLink && banAppealsLink.length > 1 && isSilent === false)
        {
            const nitroSafety = `${ global.locale[global.findLocale(message.guild.id)].nitroSafety.replaceAll(`%guildName%`, `${ guild.name }`).replaceAll(`%banAppealsLink%`, `${ banAppealsLink }`) }`;
            const standardMessage = `${ global.locale[global.findLocale(message.guild.id)].standardBanDM.replaceAll(`%guildName%`, `${ guild.name }`).replaceAll(`%banAppealsLink%`, `${ banAppealsLink }`) }`;
            await (reason.toLowerCase().includes(`nitro`) || reason.toLowerCase().includes(`scam`) ? member.send(nitroSafety).catch(() => logging.log(`Could not DM, ignoring`)) : member.send(standardMessage).catch(() => logging.warn(`Could not DM, ignoring`)));
        }

        member.ban({ deleteMessageSeconds: 7 * 24 * 60 * 60, reason: `${ authorTag } | ${ reason }` });
        ban.sendBanEmbed(Discord, client, member.id, member.user.username, message.author.id, reason, message.guild.id, time);
        var newReason = `🔨 ${ reason }`;
        await sqlite.modifyPunishmentsProfile(client, id, message.author.id, message.guild.id, `bans`, 1, newReason, timeForMuteMeta);
    }
};
