import SQLite from "better-sqlite3";
import mentions from "../../../utils/mentions.js";
import common from "../../../utils/common.js";
import mute from "../../commands/moderation/mute.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    name: `mute`,
    aliases: [`m`],

    async execute(message, ourArguments, Discord, client)
    {
        const { mutedRoleID } = common.getGuildConfig(message.guild.id);

        if (!common.canRunCommand(message, `ManageRoles`))
            return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].noPermission }`);

        if ((!mutedRoleID)
            || mutedRoleID.length < 10)
            return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].noMuteRole }`);

        const role = message.guild.roles.cache.find((r) => r.id === mutedRoleID);
        if (!role)
            return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].badMuteRole }`);

        if (!ourArguments[0])
            return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].mentionUser }`);

        var id = ourArguments[0];
        if (id[0] === `<`)
            id = mentions.getUserFromMention(ourArguments[0]);

        const guild = client.guilds.cache.get(message.guild.id);
        const member = await common.getGuildMember(client, message.guild.id, id);

        if (member && member.roles.highest.position >= message.member.roles.highest.position && guild.ownerId !== message.author.id)
            return message.channel.send(`<@!${ message.author.id }>, ${ global.locale[global.findLocale(message.guild.id)].cantMute }`);

        var reason = `${ global.locale[global.findLocale(message.guild.id)].noReasonSpecified }`;
        let time = 0;
        var isExtending = false;
        const row = sql.prepare(`SELECT * FROM mutes WHERE guildId = ? AND userId = ?`).get(message.guild.id, id);

        if (ourArguments[1])
        { // args[1] can either be a duration or a reason
            const Time = ourArguments[1];
            time = await common.getEpoch(Time, false);
            if (time !== -1337)
            {
                reason = ourArguments.slice(2).join(` `);
                if (!reason || !ourArguments[2])
                    reason = `${ global.locale[global.findLocale(message.guild.id)].noReasonSpecified }`;
                reason = common.truncateString(reason, 256);

                if (row && row.time > 1)
                { // If they are already muted, and have a punishment, take their current mute time and add the new time to it.
                    isExtending = true;
                    time = Number.parseInt(row.time, 10) + time;
                    await mute.sendMuteToDB(client, message.guild.id, message.author.id, id, time, reason, Time);
                }
                else if (row && row.time < 1)
                    return message.channel.send(`${ global.locale[global.findLocale(message.guild.id)].permMute }`);
                else if (member && member.roles.cache.some((r) => r.id === mutedRoleID)) // If they are muted, but do not have a punishment (i.e. a manual mute), assume the manual mute is what we want.
                    return message.channel.send(`${ global.locale[global.findLocale(message.guild.id)].manualMute }`);
                else
                { // fresh temp mute
                    await mute.sendMuteToDB(client, message.guild.id, message.author.id, id, Date.now() + time, reason, Time);
                }
            }
            else if (row && row.time > 1)
            { // args[1] is a reason, so we perma mute
                reason = ourArguments.slice(1).join(` `);
                if (!reason || !ourArguments[1])
                    reason = `${ global.locale[global.findLocale(message.guild.id)].noReasonSpecified }`;
                reason = common.truncateString(reason, 256);
                time = -1;
                await mute.sendMuteToDB(client, message.guild.id, message.author.id, id, time, reason);
            }
            else
            { // fresh perma mute
                reason = ourArguments.slice(1).join(` `); // We don't need to sanity check this since we know args[1] to be a reason.
                reason = common.truncateString(reason, 256);
                time = -1;
                await mute.sendMuteToDB(client, message.guild.id, message.author.id, id, time, reason);
            }
        }
        else
        { // we did not provide args[1], so assume we want to perma mute without a reason.
            reason = `${ global.locale[global.findLocale(message.guild.id)].noReasonSpecified }`;
            time = -1;
            await mute.sendMuteToDB(client, message.guild.id, message.author.id, id, time, reason);
        }

        const authorTag = message.author.tag;

        // Boot them from VC
        if (member && member.voice)
            member.voice.disconnect();

        mute.handleMute(Discord, client, member, message.author.id, role, authorTag, reason, time, isExtending, message.guild.id, id); // handles rest of mute process
    }
};
