import { createRequire } from "node:module";

import common from "../../../utils/common.js";
import logging from "../../../utils/logging.js";

import unban from "../../commands/moderation/unban.js";

const require = createRequire(import.meta.url);
const { clientSecret, token } = require(`../../../config.json`);

export default {
    name: `forcejoin`,
    async execute(message, ourArguments, Discord, client)
    {
        if (message.author.id !== client.user.id)
            return; // only the bot can use this command

        const userId = ourArguments[0];
        const token = ourArguments[1];

        const successForceJoin = await this.forceJoinUser(message, userId, token, undefined, Discord, client);
        if (!successForceJoin.success)
            message.channel.send(`${ global.locale[global.findLocale(message.guild.id)].somethingWentWrong } ${ successForceJoin.error }`);
    },

    async forceJoinUser(interactionOrMessage, userId, refreshToken, reason, Discord, client)
    {
        if (!refreshToken || !userId)
            return { success: false, error: `Missing token or user ID.` };

        const { banAppealsLink } = common.getGuildConfig(interactionOrMessage.guild.id);
        const clientId = client.user.id;

        // get fresh & new access token
        /* eslint-disable camelcase */
        const oauthData = await common.fetchJsonResponse(
            `${ common.DISCORD_API_URL }/oauth2/token`,
            {
                method: `POST`,
                body: new URLSearchParams({
                    client_id: clientId,
                    client_secret: clientSecret,
                    refresh_token: refreshToken,
                    grant_type: `refresh_token`
                }),
                headers: {
                    'Content-Type': `application/x-www-form-urlencoded`,
                }
            }
        );
        /* eslint-enable camelcase */
        if (!oauthData)
            return { success: false, error: `Failed to regenerate oauth token for ${ userId }.` };

        if (!reason)
            reason = `Auto Mod: Solved captcha for account age.`;

        const accessToken = oauthData.access_token;
        await unban.unbanUser(interactionOrMessage, userId, client.user.id, client.user.tag, reason, Discord, client).catch(() =>
        {
            logging.warn(`Could not unban or user is not banned.`);
        });
        await common.sleep(1500); // give discord time to process

        // before sending the PUT request, add the user to a whitelist list where they can bypass future alt checks
        common.whitelistedAltUsers.push(userId);
        await common.sleep(1500); // give some time to process

        /* eslint-disable camelcase */
        const unbanRequest = await common.fetchJsonResponse(
            `${ common.DISCORD_API_URL }/guilds/${ interactionOrMessage.guild.id }/members/${ userId }`,
            {
                method: `PUT`,
                body: JSON.stringify({
                    access_token: accessToken
                }),
                headers: {
                    Authorization: `Bot ${ token }`,
                    'Content-Type': `application/json`
                }
            }
        );
        /* eslint-enable camelcase */
        if (!unbanRequest)
            return { success: false, error: `Could not PUT user ${ userId } into guild.` };

        const member = await common.getGuildMember(client, interactionOrMessage.guild.id, userId, true);
        if (member && banAppealsLink && banAppealsLink.length > 1)
            await member.send(`:partying_face: ${ global.locale[global.findLocale(interactionOrMessage.guild.id)].unbanDM } <${ banAppealsLink }/revoke-permissions>`).catch(() => logging.warn(`Could not DM, ignoring`));

        return { success: true };
    }
};
