import st from "string-table";
import common from "../../../utils/common.js";

export default {
    guildlist
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {Discord} Discord The Discord client.
 * @param {Discord.client} client The client.
 * @param {boolean} onlyCount Should we only return the number of guilds it is in?
 */
export async function guildlist(interactionOrMessage, isSlashCommand, Discord, client, onlyCount = false)
{
    const guilds = client.guilds.cache.map((guild) => guild.id);
    if (onlyCount)
    {
        const lengthMessage = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].amountOfGuilds.replaceAll(`%count%`, `${ guilds.length }`) }`;
        return common.sendInteractionOrMessage(interactionOrMessage, { content: lengthMessage }, isSlashCommand);
    }

    const data = [];
    for (const guildId of guilds)
    {
        data.push({
            guildName: client.guilds.cache.get(guildId).name,
            guildId,
            guildOwner: await client.guilds.cache.get(guildId).fetchOwner().then((owner) => owner.user.tag),
            memberCount: await client.guilds.cache.get(guildId).memberCount,
            channelCount: await client.guilds.cache.get(guildId).channels.cache.size,
            roleCount: await client.guilds.cache.get(guildId).roles.cache.size,
        });
    }
    const testString = `\`\`\`${ st.create(data) }\n\`\`\``;
    if (testString.length < 2000)
    {
        const string = `\`\`\`${ st.create(data) }\n\`\`\``;
        common.sendInteractionOrMessage(interactionOrMessage, { content: string }, isSlashCommand);
    }
    else
    {
        const string = `${ st.create(data) }`;
        // send message as attachment
        const attachment = new Discord.AttachmentBuilder(Buffer.from(string), { name: `guildlist.txt` });
        common.sendInteractionOrMessage(interactionOrMessage, { files: [attachment] }, isSlashCommand);
    }
}
