import SQLite from "better-sqlite3";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    list, add, remove
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {Discord} Discord The Discord object.
 */
export async function list(interactionOrMessage, isSlashCommand, Discord)
{
    const approvedLinksH = sql.prepare(`SELECT link FROM allowedLinks WHERE guildId = ${ interactionOrMessage.guild.id }`).raw().all();
    const approvedLinks = approvedLinksH.flat();

    if (approvedLinks.length === 0)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].noLinksInList
        }, isSlashCommand);
    }

    let string = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].allowedLinks } \`${ approvedLinks.join(`\`, \``) }\``;
    if (string.length < 2000)
        common.sendInteractionOrMessage(interactionOrMessage, { content: string }, isSlashCommand);
    else
    {
        string = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].allowedLinks } \n${ approvedLinks.join(`\n`) }`;
        // send message as attachment
        const attachment = new Discord.AttachmentBuilder(Buffer.from(string), { name: `allowed-links.txt` });
        common.sendInteractionOrMessage(interactionOrMessage, { files: [attachment] }, isSlashCommand);
    }
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The guild ID.
 * @param {string} link The link to add.
 */
export async function add(interactionOrMessage, isSlashCommand, guildId, link)
{
    if (link.length > 1900)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].itemTooLong
        }, isSlashCommand);
    }

    try
    {
        sql.prepare(`INSERT INTO allowedLinks (link, guildId) VALUES (?, ?)`).run(link, guildId);
    }
    catch (error)
    {
        return console.error(error);
    }

    common.sendInteractionOrMessage(interactionOrMessage, { content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].addedToList.replaceAll(`%item%`, `${ link }`) }, isSlashCommand);
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The guild ID.
 * @param {string} link The link to remove.
 */
export async function remove(interactionOrMessage, isSlashCommand, guildId, link)
{
    try
    {
        sql.prepare(`DELETE FROM allowedLinks WHERE link = ? AND guildId = ?`).run(link, guildId);
    }
    catch (error)
    {
        return console.error(error);
    }

    common.sendInteractionOrMessage(interactionOrMessage, { content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].removedFromList.replaceAll(`%item%`, `${ link }`) }, isSlashCommand);
}
