import SQLite from "better-sqlite3";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    list, add, remove
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {*} Discord The Discord Object.
 */
export async function list(interactionOrMessage, isSlashCommand, Discord)
{
    const autoBanWordsH = sql.prepare(`SELECT phrase FROM autoBannedPhrases WHERE guildId = ${ interactionOrMessage.guild.id }`).raw().all();
    const autoBanWords = autoBanWordsH.flat();

    if (autoBanWords.length === 0)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].noAutoBannedPhrases
        }, isSlashCommand);
    }

    let string = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].autoBannedPhrases } \`${ autoBanWords.join(`\`, \``) }\``;
    if (string.length < 2000)
        common.sendInteractionOrMessage(interactionOrMessage, { content: string }, isSlashCommand);
    else
    {
        string = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].autoBannedPhrases } \n${ autoBanWords.join(`\n`) }`;

        // send message as attachment
        const attachment = new Discord.AttachmentBuilder(Buffer.from(string), { name: `auto-banned-phrases.txt` });
        common.sendInteractionOrMessage(interactionOrMessage, { files: [attachment] }, isSlashCommand);
    }
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} phrase The auto banned phrase to add.
 */
export async function add(interactionOrMessage, isSlashCommand, phrase)
{
    if (phrase.length > 1900)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].itemTooLong
        }, isSlashCommand);
    }

    try
    {
        sql.prepare(`INSERT INTO autoBannedPhrases (guildId, phrase) VALUES (?, ?)`).run(interactionOrMessage.guild.id, phrase);
    }
    catch (error)
    {
        return console.error(error);
    }

    common.sendInteractionOrMessage(interactionOrMessage, { content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].addedToList.replaceAll(`%item%`, `${ phrase }`) }, isSlashCommand);
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 * @param {string} phrase The phrase to remove.
 */
export async function remove(interactionOrMessage, isSlashCommand, guildId, phrase)
{
    try
    {
        sql.prepare(`DELETE FROM autoBannedPhrases WHERE guildId = ? AND phrase = ?`).run(guildId, phrase);
    }
    catch (error)
    {
        return console.error(error);
    }

    common.sendInteractionOrMessage(interactionOrMessage, { content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].removedFromList.replaceAll(`%item%`, `${ phrase }`) }, isSlashCommand);
}
