import SQLite from "better-sqlite3";
import st from "string-table";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    clear, list, add, remove
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 */
export async function clear(interactionOrMessage, isSlashCommand, guildId)
{
    sql.prepare(`DELETE FROM keywords WHERE guildId = ${ guildId }`).run();
    sql.prepare(`DELETE FROM keywordsRegional WHERE guildId = ${ guildId }`).run();

    common.sendInteractionOrMessage(interactionOrMessage, {
        content: `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].clearedKeywords }`
    }, isSlashCommand);
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 * @param {*} Discord The Discord Object.
 */
export async function list(interactionOrMessage, isSlashCommand, guildId, Discord)
{
    const responseObject = sql.prepare(`SELECT * FROM keywords WHERE guildId = ${ guildId }`).raw().all();
    const responseObjectRegional = sql.prepare(`SELECT * FROM keywordsRegional WHERE guildId = ${ guildId }`).raw().all();

    const data = [];
    for (const element of responseObject)
    {
        data.push({
            trigger: element[1],
            response: element[2]
        });
    }

    const dataRegional = [];
    for (const element of responseObjectRegional)
    {
        dataRegional.push({
            trigger: element[1],
            response: element[2]
        });
    }

    let string = ``;
    if (data.length > 0)
        string += `**${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].keywords }**\n\`\`\`${ st.create(data) }\n\`\`\``;

    if (dataRegional.length > 0)
        string += `\n**${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].keywordsRegional }**\n\`\`\`${ st.create(dataRegional) }\n\`\`\``;

    if (string === ``)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].noKeywords
        }, isSlashCommand);
    }

    if (string.length < 2000)
        return common.sendInteractionOrMessage(interactionOrMessage, { content: string }, isSlashCommand);

    string = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].keywords }\n${ st.create(data) }\n\n${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].keywordsRegional }\n${ st.create(dataRegional) }`;
    // send message as attachment
    const attachment = new Discord.AttachmentBuilder(Buffer.from(string), { name: `auto-replies.txt` });
    common.sendInteractionOrMessage(interactionOrMessage, { files: [attachment] }, isSlashCommand);
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 * @param {string} trigger The trigger to add.
 * @param {string} response The response to add.
 * @param {boolean} isRegional Whether or not the keyword is regional.
 */
export async function add(interactionOrMessage, isSlashCommand, guildId, trigger, response, isRegional)
{
    const responseObject = sql.prepare(`SELECT * FROM keywords WHERE guildId = ${ guildId }`).raw().all();
    const responseObjectRegional = sql.prepare(`SELECT * FROM keywordsRegional WHERE guildId = ${ guildId }`).raw().all();
    if (isRegional)
    {
        if (responseObjectRegional.some((x) => x[1] === trigger))
        {
            return common.sendInteractionOrMessage(interactionOrMessage, {
                content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].triggerAlreadyExists
            }, isSlashCommand);
        }

        sql.prepare(`INSERT INTO keywordsRegional (guildId, phrase, response) VALUES (?, ?, ?)`).run(guildId, trigger, response);
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].autoReplyAdded
        }, isSlashCommand);
    }

    if (responseObject.some((x) => x[1] === trigger))
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].triggerAlreadyExists
        }, isSlashCommand);
    }

    sql.prepare(`INSERT INTO keywords (guildId, phrase, response) VALUES (?, ?, ?)`).run(guildId, trigger, response);
    common.sendInteractionOrMessage(interactionOrMessage, {
        content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].autoReplyAdded
    }, isSlashCommand);
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 * @param {string} trigger The trigger to remove.
 * @param {boolean} isRegional Whether or not the keyword is regional.
 */
export async function remove(interactionOrMessage, isSlashCommand, guildId, trigger, isRegional)
{
    if (isRegional)
    {
        const responseObject = sql.prepare(`SELECT * FROM keywordsRegional WHERE guildId = ${ guildId }`).raw().all();
        if (!responseObject.some((x) => x[1] === trigger))
        {
            return common.sendInteractionOrMessage(interactionOrMessage, {
                content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].triggerDoesNotExist
            }, isSlashCommand);
        }

        sql.prepare(`DELETE FROM keywordsRegional WHERE guildId = ${ guildId } AND phrase = ?`).run(trigger);
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].autoReplyRemoved
        }, isSlashCommand);
    }

    const responseObject = sql.prepare(`SELECT * FROM keywords WHERE guildId = ${ guildId }`).raw().all();
    if (!responseObject.some((x) => x[1] === trigger))
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].triggerDoesNotExist
        }, isSlashCommand);
    }

    sql.prepare(`DELETE FROM keywords WHERE guildId = ${ guildId } AND phrase = ?`).run(trigger);
    return common.sendInteractionOrMessage(interactionOrMessage, {
        content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].autoReplyRemoved
    }, isSlashCommand);
}
