import SQLite from "better-sqlite3";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    list, add, remove
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {*} Discord The Discord Object.
 */
export async function list(interactionOrMessage, isSlashCommand, Discord)
{
    const badWordsH = sql.prepare(`SELECT word FROM badWords WHERE guildId = ${ interactionOrMessage.guild.id }`).raw().all();
    const badWords = badWordsH.flat();

    if (badWords.length === 0)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].noBadWords
        }, isSlashCommand);
    }

    let string = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].badWords } \`${ badWords.join(`\`, \``) }\``;
    if (string.length < 2000)
        common.sendInteractionOrMessage(interactionOrMessage, { content: string }, isSlashCommand);
    else
    {
        string = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].badWords } \n${ badWords.join(`\n`) }`;

        // send message as attachment
        const attachment = new Discord.AttachmentBuilder(Buffer.from(string), { name: `bad-words.txt` });
        common.sendInteractionOrMessage(interactionOrMessage, { files: [attachment] }, isSlashCommand);
    }
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 * @param {string} phrase The phrase to add.
 */
export async function add(interactionOrMessage, isSlashCommand, guildId, phrase)
{
    if (phrase.length > 1900)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].itemTooLong
        }, isSlashCommand);
    }

    try
    {
        sql.prepare(`INSERT INTO badWords (guildId, word) VALUES (?, ?)`).run(guildId, phrase);
    }
    catch (error)
    {
        return console.error(error);
    }

    common.sendInteractionOrMessage(interactionOrMessage, { content: `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].badWordAdded } \`${ phrase }\`` }, isSlashCommand);
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 * @param {string} phrase The phrase to remove.
 */
export async function remove(interactionOrMessage, isSlashCommand, guildId, phrase)
{
    try
    {
        sql.prepare(`DELETE FROM badWords WHERE guildId = ? AND word = ?`).run(guildId, phrase);
    }
    catch (error)
    {
        return console.error(error);
    }

    common.sendInteractionOrMessage(interactionOrMessage, {
        content: `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].badWordRemoved } \`${ phrase }\``
    }, isSlashCommand);
}
