import SQLite from "better-sqlite3";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    list, add, remove
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {*} Discord The Discord Object.
 */
export async function list(interactionOrMessage, isSlashCommand, Discord)
{
    const dmListH = sql.prepare(`SELECT userId FROM doNotForwardDMsFrom`).raw().all();
    const dmList = dmListH.flat();

    if (dmList.length === 0)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].noIgnoredDMs
        }, isSlashCommand);
    }
    let string = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].ignoredDMs } \`${ dmList.join(`\`, \``) }\``;
    if (string.length < 2000)
        common.sendInteractionOrMessage(interactionOrMessage, { content: string }, isSlashCommand);
    else
    {
        string = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].ignoredDMs } \n${ dmList.join(`\n`) }`;

        // send message as attachment
        const attachment = new Discord.AttachmentBuilder(Buffer.from(string), { name: `ignore-dms.txt` });
        common.sendInteractionOrMessage(interactionOrMessage, { files: [attachment] }, isSlashCommand);
    }
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {number} uid The user ID.
 */
export async function add(interactionOrMessage, isSlashCommand, uid)
{
    const dmListH = sql.prepare(`SELECT userId FROM doNotForwardDMsFrom`).raw().all();
    const dmList = dmListH.flat();

    if (dmList.includes(uid))
        return common.sendInteractionOrMessage(interactionOrMessage, { content: `<@!${ uid }> ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].isAlreadyIgnored }` }, isSlashCommand);

    try
    {
        sql.prepare(`INSERT INTO doNotForwardDMsFrom (userId) VALUES (?)`).run(uid);
    }
    catch (error)
    {
        return console.error(error);
    }

    common.sendInteractionOrMessage(interactionOrMessage, {
        content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].userIgnored
    }, isSlashCommand);
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {number} uid The user ID.
 */
export async function remove(interactionOrMessage, isSlashCommand, uid)
{
    try
    {
        sql.prepare(`DELETE FROM doNotForwardDMsFrom WHERE userId = ?`).run(uid);
    }
    catch (error)
    {
        return console.error(error);
    }

    common.sendInteractionOrMessage(interactionOrMessage, {
        content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].userUnignored
    }, isSlashCommand);
}
