import SQLite from "better-sqlite3";
import sqlite from "../../../utils/sqlite.js";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    clearWarns,
};

/**
 * @param {*} client The Discord Client Object.
 * @param {*} Discord The Discord Object.
 * @param {string} guildId The Guild ID.
 * @param {string} id The ID of the user to clear warns for.
 * @param {Discord.GuildMember} member The GuildMember object.
 * @param {string} authorId The ID of the user who issued the command.
 * @param {string} reason The reason for the clear.
 */
export async function clearWarns(client, Discord, guildId, id, member, authorId, reason)
{
    var warnings = sqlite.getPunishmentData(guildId, id, `warns`);
    if (warnings >= 1)
    {
        const data = global.getInfoById.get(guildId, id);
        var punishmentinfo = JSON.parse(data.punishmentinfo);
        var punishmentreason = JSON.parse(data.punishmentreason);

        for (let index = 0; index < punishmentreason.length;)
        {
            if (punishmentreason[index].includes(`⚠`))
            {
                punishmentreason.splice(index, 1);
                punishmentinfo.splice(index, 1);

                // apply data
                data.punishmentinfo = JSON.stringify(punishmentinfo);
                data.punishmentreason = JSON.stringify(punishmentreason);
                data.warns -= 1;
                global.setInfo.run(data);
            }
            else
                index += 1; // only up 1 index if no warning reason was found. this solves the issue of back-to-back warnings and we skip over 1
        }
    }

    // If the user has 0 history now, delete their record.
    if (!sqlite.hasRecord(guildId, id))
        sql.prepare(`DELETE FROM punishments WHERE guildId = ? AND id = ?`).run(guildId, id);

    const { auditChannelID } = common.getGuildConfig(guildId);
    if (!auditChannelID || auditChannelID.length < 10) return; // no audit channel ID, dont try and send an embed
    const auditChannel = client.channels.cache.get(auditChannelID);
    if (!auditChannel) // auditChannelID is invalid.
        return;
    const embed = new Discord.EmbedBuilder()
        .setColor(`#00FF00`)
        .setTimestamp()
        .setAuthor({ name: `⚠️ (${ global.locale[global.findLocale(guildId)].clearWarns })` })
        .addFields([{ name: `${ global.locale[global.findLocale(guildId)].user }`, value: `<@!${ member.id }> (${ member.username })`, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(guildId)].moderator }`, value: `<@!${ authorId }>`, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(guildId)].reason }`, value: reason, inline: true }]);

    auditChannel.send({ embeds: [embed] });
}
