import SQLite from "better-sqlite3";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    duration
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 * @param {string} targetId The target ID.
 * @param {string} moderatorId The moderator ID.
 * @param {number} newDurationEpoch The new duration in epoch.
 * @param {string} newDurationText The new duration text (i.e. 3d or whatever).
 * @param {string} reason The reason for the duration change.
 */
export async function duration(interactionOrMessage, isSlashCommand, guildId, targetId, moderatorId, newDurationEpoch, newDurationText, reason)
{
    // Update punishments punishmentinfo for latest punishment
    const punishmentRow = sql.prepare(`SELECT * FROM punishments WHERE id = ? AND guildId = ?`).get(targetId, guildId);
    const parsedJsonReason = JSON.parse(punishmentRow.punishmentreason);
    // From the end of the array, find the index of the last punishment
    let index;
    for (index = parsedJsonReason.length - 1; index >= 0; index--)
    {
        if (parsedJsonReason[index].startsWith(`🤫 `) || parsedJsonReason[index].startsWith(`🔨 `))
            break;
    }
    const parsedJsonMeta = JSON.parse(punishmentRow.punishmentinfo);
    parsedJsonMeta[index] = `<@!${ moderatorId }> ${ global.locale[global.findLocale(interactionOrMessage.guild.id)].at } <t:${ Math.round(Date.now() / 1000) }> ${ global.locale[global.findLocale(interactionOrMessage.guild.id)].for } ${ newDurationText }`;
    sql.prepare(`UPDATE punishments SET punishmentinfo = ? WHERE id = ? AND guildId = ?`).run(JSON.stringify(parsedJsonMeta), targetId, guildId);

    if (parsedJsonReason[index].startsWith(`🤫 `))
        sql.prepare(`UPDATE mutes SET time = ?, moderatorId = ? WHERE userId = ? AND guildId = ?`).run(newDurationEpoch, moderatorId, targetId, guildId);
    else if (parsedJsonReason[index].startsWith(`🔨 `))
        sql.prepare(`REPLACE INTO tempbanUsers VALUES (?, ?, ?, ?, ?)`).run(`${ guildId }_${ targetId }`, guildId, targetId, newDurationEpoch, moderatorId);

    common.sendInteractionOrMessage(interactionOrMessage, global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].changedDuration.replaceAll(`%targetId%`, targetId).replaceAll(`%newDurationText%`, newDurationText).replaceAll(`%reason%`, reason), isSlashCommand);
}
