import sqlite from "../../../utils/sqlite.js";
import common from "../../../utils/common.js";

export default {
    kick
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} targetId The target ID.
 * @param {string} moderatorId The moderator ID.
 * @param {string} reason The reason for the kick.
 * @param {*} Discord The Discord Object.
 * @param {*} client The Discord Client Object.
 */
export async function kick(interactionOrMessage, isSlashCommand, targetId, moderatorId, reason, Discord, client)
{
    const guildId = interactionOrMessage.guild.id;
    const { auditChannelID } = common.getGuildConfig(guildId);

    const guild = client.guilds.cache.get(interactionOrMessage.guild.id);
    const member = await common.getGuildMember(client, interactionOrMessage.guild.id, targetId);

    if (!member)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].cantFetchUser
        }, isSlashCommand);
    }

    if (!reason)
        reason = `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].noReasonSpecified }`;
    reason = common.truncateString(reason, 256);
    const moderator = await common.getGuildMember(client, interactionOrMessage.guild.id, moderatorId);
    const authorTag = moderator.tag;

    if ((member.roles.highest.position >= moderator.roles.highest.position && guild.ownerId !== moderatorId) || !member.kickable)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].cantKickUser
        }, isSlashCommand);
    }

    member.kick(`${ authorTag } | ${ reason }`);
    var newReason = `🦶 ${ reason }`;
    await sqlite.modifyPunishmentsProfile(client, targetId, moderatorId, guildId, `kicks`, 1, newReason);

    if (!auditChannelID || auditChannelID.length < 10) return; // No audit channel set.
    const auditChannel = client.channels.cache.get(auditChannelID);
    if (!auditChannel) // auditChannelID is invalid.
        return;
    const embed = new Discord.EmbedBuilder()
        .setColor(`#ff1e00`)
        .setTimestamp()
        .setAuthor({ name: `🦶 (${ global.locale[global.findLocale(interactionOrMessage.guild.id)].kick })` })
        .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].user }`, value: `<@!${ member.id }> (${ member.user.username })`, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].moderator }`, value: `<@!${ moderatorId }>`, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].reason }`, value: reason, inline: true }]);

    auditChannel.send({ embeds: [embed] });
}
