import common from "../../../utils/common.js";

export default {
    lockdown
};

/**
 * @param {boolean} doLockdown Whether or not to lockdown/unlock the server.
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} reason The reason for the lockdown.
 * @param {*} Discord The Discord Object.
 * @param {*} client The Discord Client Object.
 * @param {string} channelId If we want to lockdown just one channel, specify it here.
 */
export async function lockdown(doLockdown, interactionOrMessage, isSlashCommand, reason, Discord, client, channelId)
{
    const guildId = interactionOrMessage.guild.id;
    const { auditChannelID, lockdownChannelIDs } = common.getGuildConfig(guildId);

    if (channelId)
        var CHANNELS_TO_MUTE = new Set([channelId]);
    else
        var CHANNELS_TO_MUTE = new Set(lockdownChannelIDs);

    // Find @everyone role ID
    const everyoneRole = interactionOrMessage.guild.roles.cache.find((r) => r.name === `@everyone`).id;

    if (!reason) reason = `No reason provided`;
    reason = common.truncateString(reason, 256);
    if (interactionOrMessage.guild.roles.cache.has(everyoneRole))
    {
        const channels = interactionOrMessage.guild.channels.cache.filter((ch) => ch.type !== `category`);

        for (let channel of channels)
        {
            channel = channel[1];
            if (CHANNELS_TO_MUTE.has(channel.id))
            {
                if (doLockdown)
                {
                    channel.permissionOverwrites.edit(everyoneRole, {
                        SendMessages: false,
                        SendMessagesInThreads: false,
                    })
                        .then((g) =>
                        {
                            if (!g.name.endsWith(`🔒`))
                                g.edit({ name: `${ g.name }-🔒` });
                        });
                }
                else if (!doLockdown)
                {
                    channel.permissionOverwrites.edit(everyoneRole, {
                        SendMessages: true,
                        SendMessagesInThreads: true,
                    })
                        .then((g) =>
                        {
                            if (g.name.endsWith(`🔒`))
                                g.edit({ name: g.name.replace(`-🔒`, ``) });
                        });
                }
            }
        }
    }

    if (!auditChannelID || auditChannelID.length < 10) return; // No audit channel ID, no need to send audit message.
    const auditChannel = client.channels.cache.get(auditChannelID);
    if (!auditChannel)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].debugBadSetup
        }, isSlashCommand);
    }

    const moderatorId = isSlashCommand ? interactionOrMessage.user.id : interactionOrMessage.author.id;

    if (doLockdown)
    {
        var embed = new Discord.EmbedBuilder()
            .setColor(`#ff0000`)
            .setTimestamp()
            .setAuthor({ name: `🔒 (${ global.locale[global.findLocale(interactionOrMessage.guild.id)].lockdownStarted })` });
        if (channelId)
            embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].channel }`, value: `<#${ channelId }>` }]);
        embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].moderator }`, value: `<@!${ moderatorId }>`, inline: true }]);
        embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].reason }`, value: reason, inline: true }]);
    }
    else
    {
        var embed = new Discord.EmbedBuilder()
            .setColor(`#00ff00`)
            .setTimestamp()
            .setAuthor({ name: `🔓 (${ global.locale[global.findLocale(interactionOrMessage.guild.id)].lockdownEnded })` });
        if (channelId)
            embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].channel }`, value: `<#${ channelId }>` }]);
        embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].moderator }`, value: `<@!${ moderatorId }>`, inline: true }]);
        embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].reason }`, value: reason, inline: true }]);
    }

    auditChannel.send({ embeds: [embed] });
}
