import SQLite from "better-sqlite3";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    /**
     * @param {*} Discord The Discord Object.
     * @param {*} client The Discord Client Object.
     * @param {string} userId The user ID.
     * @param {string} guildId The Guild ID.
     * @param {boolean} isPublic Whether or not to hide punishments.
     * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
     * @param {*} interactionOrMessage The interaction or message object.
     */
    async lookup(Discord, client, userId, guildId, isPublic, isSlashCommand, interactionOrMessage)
    {
        const guild = client.guilds.cache.get(guildId);
        const guildMember = await common.getGuildMember(client, guildId, userId);
        const user = await common.getUser(client, userId);

        if (guild.members.cache.get(userId) && guildMember) // is in guild, let's use GuildMember
        {
            // handle listing roles
            var roles = ``;
            guildMember.roles.cache.each((value) =>
            {
                if (value.name !== `@everyone`)
                    roles += `<@&${ value.id }>\n`;
            });

            var embed = new Discord.EmbedBuilder()
                .setColor(`#0e9af9`)
                .setTimestamp()
                .setAuthor({ name: `🔎 (${ global.locale[global.findLocale(interactionOrMessage.guild.id)].lookup })` })
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].name }`, value: `**${ guildMember.user.username }**#${ guildMember.user.discriminator }`, inline: true }])
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].id }`, value: `${ guildMember.id }`, inline: true }])
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].mention }`, value: `<@!${ guildMember.id }>`, inline: true }])
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].accountCreated }`, value: `<t:${ Math.round(guildMember.user.createdTimestamp / 1000) }>`, inline: true }])
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].joinedServer }`, value: `<t:${ Math.round(guildMember.joinedTimestamp / 1000) }>`, inline: true }])
                .setThumbnail(
                    `${ guildMember.displayAvatarURL({ dynamic: true, size: 1024 }) }`
                );

            if (guildMember.roles.cache.size > 1)
                embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].roles } (${ guildMember.roles.cache.size - 1 })`, value: roles, inline: true }]);
        }
        else
        {
            if (!user)
            {
                return common.sendInteractionOrMessage(interactionOrMessage, {
                    content: global.locale[global.findLocale(interactionOrMessage.guild.id)].noId
                }, isSlashCommand);
            }

            var embed = new Discord.EmbedBuilder()
                .setColor(`#ff1e00`)
                .setTimestamp()
                .setAuthor({ name: `🔎 (${ global.locale[global.findLocale(interactionOrMessage.guild.id)].lookup })` })
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].name }`, value: `**${ user.username }**#${ user.discriminator }`, inline: true }])
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].id }`, value: `${ user.id }`, inline: true }])
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].mention }`, value: `<@!${ user.id }>`, inline: true }])
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].accountCreated }`, value: `<t:${ Math.round(user.createdTimestamp / 1000) }>`, inline: true }])
                .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].inServer }`, value: `No`, inline: true }])
                .setThumbnail(
                    `${ user.displayAvatarURL({ dynamic: true, size: 1024 }) }`
                );
        }

        if (isPublic)
            return common.sendInteractionOrMessage(interactionOrMessage, { embeds: [embed] }, isSlashCommand);

        const punishmentList = new Discord.EmbedBuilder();
        const data = global.getInfoById.get(guildId, userId);
        if (data)
        {
            if (data.warns > 0)
                embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].warns }`, value: `${ data.warns }`, inline: true }]);
            if (data.mutes > 0)
                embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].mutes }`, value: `${ data.mutes }`, inline: true }]);
            if (data.kicks > 0)
                embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].kicks }`, value: `${ data.kicks }`, inline: true }]);
            if (data.bans > 0)
                embed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].bans }`, value: `${ data.bans }`, inline: true }]);

            punishmentList.setColor(`#ff1e00`);

            if (guildMember)
            {
                punishmentList.setAuthor({
                    name: `${ guildMember.user.username }#${ guildMember.user.discriminator }'s ${ global.locale[global.findLocale(interactionOrMessage.guild.id)].history }`,
                    iconURL: `${ guildMember.user.displayAvatarURL({ dynamic: true, size: 1024 }) }`
                });
            }
            else
            {
                punishmentList.setAuthor({
                    name: `${ user.username }#${ user.discriminator }'s ${ global.locale[global.findLocale(interactionOrMessage.guild.id)].history }`,
                    iconURL: `${ user.displayAvatarURL({ dynamic: true, size: 1024 }) }`
                });
            }

            var noteData = JSON.parse(data.punishmentreason);
            var punishInfo = JSON.parse(data.punishmentinfo);
            const amountOfPunishments = noteData.length;

            if (noteData.length > 22)
                noteData.length = 22; // Lets us add the three embed fields below without running into issues.

            for (const [index, noteDatum] of noteData.entries())
            {
                if (noteDatum && punishInfo[index])
                    punishmentList.addFields([{ name: `\`${ index + 1 }.\` ${ noteDatum }`, value: `${ punishInfo[index] }`, inline: false }]);
            }

            if (amountOfPunishments > 22)
                punishmentList.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].note }:`, value: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].userHasALotOfPunishments }`, inline: false }]);

            const punishmentTitle = `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].muteExpires }`;
            const row = sql.prepare(`SELECT * FROM mutes WHERE guildId = ? AND userId = ?`).get(guildId, userId);
            if (row && row.time > 0)
                punishmentList.addFields([{ name: punishmentTitle, value: `<t:${ Math.round((row.time) / 1000) }:R>`, inline: false }]);

            else if (row && row.time === -1)
                punishmentList.addFields([{ name: punishmentTitle, value: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].never }`, inline: false }]);

            const editCaseInfoHeader = `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].modifyingHistory }`;
            const editCaseInfo = `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].modifyingHistoryDesc }`;
            punishmentList.addFields([{ name: editCaseInfoHeader, value: editCaseInfo, inline: false }]);
        }

        const notesEmbed = new Discord.EmbedBuilder();
        const notesData = sql.prepare(`SELECT * FROM userNotes WHERE guildId = ? AND userId = ?`).get(guildId, userId);
        if (notesData)
        {
            notesEmbed.setColor(`#FFFFFF`);

            if (guildMember)
            {
                notesEmbed.setAuthor({
                    name: `${ guildMember.user.username }#${ guildMember.user.discriminator }'s ${ global.locale[global.findLocale(interactionOrMessage.guild.id)].notes }`,
                    iconURL: `${ guildMember.user.displayAvatarURL({ dynamic: true, size: 1024 }) }`
                });
            }
            else
            {
                notesEmbed.setAuthor({
                    name: `${ user.username }#${ user.discriminator }'s ${ global.locale[global.findLocale(interactionOrMessage.guild.id)].notes }`,
                    iconURL: `${ user.displayAvatarURL({ dynamic: true, size: 1024 }) }`
                });
            }

            var noteData = JSON.parse(notesData.note);
            var noteMeta = JSON.parse(notesData.meta);
            const amountOfNotes = noteData.length;

            if (noteData.length > 24)
                noteData.length = 24; // Lets us add the three embed fields below without running into issues.

            for (const [index, noteDatum] of noteData.entries())
            {
                if (noteDatum && noteMeta[index])
                    notesEmbed.addFields([{ name: `\`${ index + 1 }.\` ${ noteDatum }`, value: `${ noteMeta[index] }`, inline: false }]);
            }

            if (amountOfNotes > 24)
                notesEmbed.addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].note }:`, value: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].tooManyNotes }`, inline: false }]);
        }

        if (data && notesData)
            return common.sendInteractionOrMessage(interactionOrMessage, { embeds: [embed, punishmentList, notesEmbed] }, isSlashCommand); // returns general + punishments + notes
        if (data && !notesData)
            return common.sendInteractionOrMessage(interactionOrMessage, { embeds: [embed, punishmentList] }, isSlashCommand); // returns general + punishments
        if (notesData)
            return common.sendInteractionOrMessage(interactionOrMessage, { embeds: [embed, notesEmbed] }, isSlashCommand); // returns notes

        common.sendInteractionOrMessage(interactionOrMessage, { embeds: [embed] }, isSlashCommand); // returns general (they dont have any punishments)
    }
};
