import common from "../../../utils/common.js";

export default {
    nick
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} targetId The target ID.
 * @param {string} newNick The new nickname.
 * @param {string} moderatorId The moderator ID.
 * @param {*} Discord The Discord Object.
 * @param {*} client The Discord Client Object.
 */
export async function nick(interactionOrMessage, isSlashCommand, targetId, newNick, moderatorId, Discord, client)
{
    const guildId = interactionOrMessage.guild.id;
    const { auditChannelID } = common.getGuildConfig(guildId);

    const guild = client.guilds.cache.get(guildId);
    const member = await common.getGuildMember(client, guildId, targetId);

    if (!member)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(guildId, interactionOrMessage.locale)].cantFetchUser
        }, isSlashCommand);
    }

    if (!newNick || newNick.length === 0)
        newNick = member.username;

    if (newNick.length > 32)
        newNick = newNick.slice(0, 32);

    const moderator = await common.getGuildMember(moderatorId);
    const authorTag = moderator.user.tag;

    if ((member.roles.highest.position >= moderator.roles.highest.position && guild.ownerId !== moderatorId)
        || member.roles.highest.comparePositionTo(guild.members.me.roles.highest) >= 0)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(guild.id, interactionOrMessage.locale)].cantRenameUser
        }, isSlashCommand);
    }

    member.setNickname(newNick, `${ global.locale[global.findLocale(guild.id)].renamedBy }: ${ authorTag }`);

    if (!auditChannelID || auditChannelID.length < 10) return; // No audit channel set, so no need to send an audit message.
    const auditChannel = client.channels.cache.get(auditChannelID);
    if (!auditChannel) // auditChannelID is invalid.
        return;
    const embed = new Discord.EmbedBuilder()
        .setColor(`#ff1e00`)
        .setTimestamp()
        .setAuthor({ name: `👤 (${ global.locale[global.findLocale(guildId)].renamed })` })
        .addFields([{ name: `${ global.locale[global.findLocale(guildId)].oldName }`, value: member.displayName, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(guildId)].newName }`, value: newNick, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(guildId)].user }`, value: `<@!${ member.id }>`, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(guildId)].moderator }`, value: `<@!${ moderatorId }>`, inline: true }]);

    auditChannel.send({ embeds: [embed] });
}
