import SQLite from "better-sqlite3";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    add, remove
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 * @param {string} targetId The target ID.
 * @param {string} moderatorId The moderator ID.
 * @param {string} noteText The note text.
 */
export async function add(interactionOrMessage, isSlashCommand, guildId, targetId, moderatorId, noteText)
{
    if (noteText.length >= 240)
    {
        noteText = noteText.slice(0, 234);
        noteText += ` [...]`;
    }

    // Check if they have an existing note
    const existingNote = sql.prepare(`SELECT * FROM userNotes WHERE guildId = ? AND userId = ?`).get(guildId, targetId);
    if (existingNote)
    {
        let noteDatabase = JSON.parse(existingNote.note);
        noteDatabase.push(noteText);
        noteDatabase = JSON.stringify(noteDatabase);
        let metaDatabase = JSON.parse(existingNote.meta);
        metaDatabase.push(`<@!${ moderatorId }> ${ global.locale[global.findLocale(interactionOrMessage.guild.id)].at } <t:${ Math.round(Date.now() / 1000) }>`);
        metaDatabase = JSON.stringify(metaDatabase);
        sql.prepare(`UPDATE userNotes SET note = ?, meta = ? WHERE guildId = ? AND userId = ?`).run(noteDatabase, metaDatabase, guildId, targetId);
    }
    else
    {
        let noteDatabase = [];
        noteDatabase.push(noteText);
        noteDatabase = JSON.stringify(noteDatabase);
        const meta = `<@!${ moderatorId }> ${ global.locale[global.findLocale(interactionOrMessage.guild.id)].at } <t:${ Math.round(Date.now() / 1000) }>`;
        let metaDatabase = [];
        metaDatabase.push(meta);
        metaDatabase = JSON.stringify(metaDatabase);
        sql.prepare(`INSERT INTO userNotes (guildAndUserId, userId, guildId, note, meta) VALUES (?, ?, ?, ?, ?)`).run(`${ guildId }_${ targetId }`, targetId, guildId, noteDatabase, metaDatabase);
    }

    let successString = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].addedNoteTo } <@!${ targetId }>.\n\`${ noteText }\``;
    successString = common.truncateString(successString, 1024);

    common.sendInteractionOrMessage(interactionOrMessage, {
        content: successString
    }, isSlashCommand);
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} guildId The Guild ID.
 * @param {string} targetId The target ID.
 * @param {string} moderatorId The moderator ID.
 * @param {string} noteId The note ID.
 */
export async function remove(interactionOrMessage, isSlashCommand, guildId, targetId, moderatorId, noteId)
{
    // Check if they have an existing note
    const existingNote = sql.prepare(`SELECT * FROM userNotes WHERE guildId = ? AND userId = ?`).get(guildId, targetId);
    if (!existingNote)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].doesNotHaveAnyNotes
        }, isSlashCommand);
    }

    let noteDatabase = JSON.parse(existingNote.note);
    let metaDatabase = JSON.parse(existingNote.meta);
    noteId -= 1;
    if (!noteDatabase[noteId])
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].doesNotaHaveANoteWithThatId
        }, isSlashCommand);
    }
    noteDatabase.splice(noteId, 1);
    metaDatabase.splice(noteId, 1);

    if (noteDatabase.length === 0)
        sql.prepare(`DELETE FROM userNotes WHERE guildId = ? AND userId = ?`).run(guildId, targetId);
    else
    {
        noteDatabase = JSON.stringify(noteDatabase);
        metaDatabase = JSON.stringify(metaDatabase);
        sql.prepare(`UPDATE userNotes SET note = ?, meta = ? WHERE guildId = ? AND userId = ?`).run(noteDatabase, metaDatabase, guildId, targetId);
    }

    common.sendInteractionOrMessage(interactionOrMessage, {
        content: `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].removedNote } ${ noteId + 1 } ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].from } <@!${ targetId }>.`
    }, isSlashCommand);
}
