import common from "../../../utils/common.js";

export default {
    start,
    end
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} friendlyTime The time in "3d" or similar.
 * @param {string} moderatorId The ID of the moderator.
 * @param {string} channelId The ID of the channel.
 * @param {string} reason The reason for the slowmode.
 * @param {*} Discord The Discord Object.
 * @param {*} client The Discord Client Object.
 */
export async function start(interactionOrMessage, isSlashCommand, friendlyTime, moderatorId, channelId, reason, Discord, client)
{
    const guildId = interactionOrMessage.guild.id;
    const { auditChannelID } = common.getGuildConfig(guildId);
    var time = 0;
    if (/^\d+[hms]$/.test(friendlyTime)) // we know its in the right format, and not a reason.
    {
        time = friendlyTime.slice(0, -1); // Get the number
        const timeUnit = friendlyTime.slice(-1); // Get the unit
        if (!reason)
            reason = `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].noReasonSpecified }`;
        reason = common.truncateString(reason, 256);

        switch (timeUnit)
        {
            case `h`: {
                if (time > 6)
                    time = 6;

                friendlyTime = `${ time } ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].hours }`;
                time = time * 60 * 60;
                break;
            }
            case `m`: {
                if (time > 360)
                    time = 360;

                friendlyTime = `${ time } ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].minutes }`;
                time *= 60;
                break;
            }
            case `s`: {
                if (time > 21_600)
                    time = 21_600;

                friendlyTime = `${ time } ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].seconds }`;
                break;
            }
            default: {
                return common.sendInteractionOrMessage(interactionOrMessage, {
                    content: global.locale[global.findLocale(interactionOrMessage.guild.id)].badTimeUnit
                }, isSlashCommand);
            }
        }

        interactionOrMessage.channel.setRateLimitPerUser(time, reason);

        if (!auditChannelID || auditChannelID.length < 10) return; // No audit channel set.
        const auditChannel = client.channels.cache.get(auditChannelID);
        if (!auditChannel) // auditChannelID is invalid.
            return;
        const embed = new Discord.EmbedBuilder()
            .setColor(`#ff1e00`)
            .setTimestamp()
            .setAuthor({ name: `⏲️ (${ global.locale[global.findLocale(interactionOrMessage.guild.id)].slowMode })` })
            .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].moderator }`, value: `<@!${ moderatorId }>`, inline: true }])
            .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].channel }`, value: `<#${ channelId }>`, inline: true }])
            .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].time }`, value: friendlyTime, inline: true }])
            .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].reason }`, value: reason, inline: true }]);
        auditChannel.send({ embeds: [embed] });
    }
    else
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id)].badTimeUnit
        }, isSlashCommand);
    }
}

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} moderatorId The ID of the moderator.
 * @param {string} channelId The ID of the channel.
 * @param {string} reason The reason for slowmode.
 * @param {*} Discord The Discord Object.
 * @param {*} client The Discord Client Object.
 */
export async function end(interactionOrMessage, isSlashCommand, moderatorId, channelId, reason, Discord, client)
{
    const guildId = interactionOrMessage.guild.id;
    const { auditChannelID } = common.getGuildConfig(guildId);

    if (!reason)
        reason = `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].noReasonSpecified }`;
    reason = common.truncateString(reason, 256);
    interactionOrMessage.channel.setRateLimitPerUser(0, reason);

    if (!auditChannelID || auditChannelID.length < 10) return; // No audit channel set.
    const auditChannel = client.channels.cache.get(auditChannelID);
    if (!auditChannel) // auditChannelID is invalid.
        return;
    const embed = new Discord.EmbedBuilder()
        .setColor(`#00FF00`)
        .setTimestamp()
        .setAuthor({ name: `⏲️ (${ global.locale[global.findLocale(interactionOrMessage.guild.id)].slowModeRemoval })` })
        .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].moderator }`, value: `<@!${ moderatorId }>`, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].channel }`, value: `<#${ channelId }>`, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].reason }`, value: reason, inline: true }]);

    return auditChannel.send({ embeds: [embed] });
}
