import sqlite from "../../../utils/sqlite.js";
import common from "../../../utils/common.js";

export default {
    softban
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} targetId The ID of the user to softban.
 * @param {string} moderatorId  The ID of the moderator who soft banned the user.
 * @param {string} reason  The reason for the softban.
 * @param {*} Discord The Discord Object.
 * @param {*} client The Discord Client Object.
 */
export async function softban(interactionOrMessage, isSlashCommand, targetId, moderatorId, reason, Discord, client)
{
    const guildId = interactionOrMessage.guild.id;
    const { auditChannelID } = common.getGuildConfig(guildId);

    const member = await common.getGuildMember(client, guildId, targetId);

    if (!member)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].cantFetchUser
        }, isSlashCommand);
    }

    if (!reason)
        reason = `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].noReasonSpecified }`;
    reason = common.truncateString(reason, 256);
    const moderator = await common.getGuildMember(client, interactionOrMessage.guild.id, moderatorId);
    const authorTag = moderator.user.tag;

    if ((member.roles.highest.position >= moderator.roles.highest.position && interactionOrMessage.guild.ownerId !== moderatorId) || !member.bannable)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].cantBanUser
        }, isSlashCommand);
    }

    await member.ban({ deleteMessageSeconds: 7 * 24 * 60 * 60, reason: `${ authorTag } | ${ reason }` });
    await interactionOrMessage.guild.members.unban(targetId, `${ authorTag } | ${ reason }`);

    var newReason = `🦶 ${ reason }`;
    await sqlite.modifyPunishmentsProfile(client, targetId, moderatorId, guildId, `kicks`, 1, newReason);

    if (!auditChannelID || auditChannelID.length < 10) return; // No audit channel set.
    const auditChannel = client.channels.cache.get(auditChannelID);
    if (!auditChannel) // auditChannelID is invalid.
        return;
    const embed = new Discord.EmbedBuilder()
        .setColor(`#ff1e00`)
        .setTimestamp()
        .setAuthor({ name: `🦶 (${ global.locale[global.findLocale(interactionOrMessage.guild.id)].softban })` })
        .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].user }`, value: `<@!${ member.id }> (${ member.user.username })`, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].moderator }`, value: `<@!${ moderatorId }>`, inline: true }])
        .addFields([{ name: `${ global.locale[global.findLocale(interactionOrMessage.guild.id)].reason }`, value: reason, inline: true }]);

    auditChannel.send({ embeds: [embed] });
}
