import { ButtonStyle } from "discord.js";

export default {
    /**
     * @param {*} interactionOrMessage The interaction or message object.
     * @param {boolean} isSlashCommand Whether or not the command is a slash command.
     * @param {string} targetingChannelId Where the embed should be sent.
     * @param {*} Discord The Discord Object.
     */
    async embedGenerator(interactionOrMessage, isSlashCommand, targetingChannelId, Discord)
    {
        const button = new Discord.ButtonBuilder()
            .setCustomId(`embedgenerator-${ targetingChannelId }`)
            .setLabel(`${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].generateEmbed }`)
            .setStyle(ButtonStyle.Primary)
            .setDisabled(false);
        const buttonArray = [button];
        const row = new Discord.ActionRowBuilder()
            .addComponents(buttonArray);

        const message = `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].embedGeneratorDestChan } <#${ targetingChannelId }>`;
        interactionOrMessage.channel.send({ content: message, components: [row] });
    },

    /**
     * @param {Discord.Interaction} interaction The interaction object.
     * @param {string} channelId The channel ID to send the embed to.
     * @param {Discord} Discord The Discord Object.
     */ async handleEmbedGenerator(interaction, channelId, Discord)
    {
        // Open a modal to generate an embed
        const modal = new Discord.ModalBuilder()
            .setTitle(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].generateEmbed }`)
            .setCustomId(`modal-embedgenerator-${ channelId }`);

        const title = new Discord.TextInputBuilder()
            .setCustomId(`embedgenerator-title`)
            .setLabel(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].embedGeneratorTitle }`)
            .setStyle(1)
            .setMinLength(0)
            .setMaxLength(250);

        const description = new Discord.TextInputBuilder()
            .setCustomId(`embedgenerator-description`)
            .setLabel(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].embedGeneratorDescription }`)
            .setStyle(2)
            .setMinLength(0)
            .setMaxLength(1000);

        const url = new Discord.TextInputBuilder()
            .setCustomId(`embedgenerator-url`)
            .setLabel(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].embedGeneratorURL }`)
            .setStyle(1)
            .setMinLength(0)
            .setMaxLength(1000)
            .setRequired(false);

        const color = new Discord.TextInputBuilder()
            .setCustomId(`embedgenerator-color`)
            .setLabel(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].embedGeneratorColor }`)
            .setStyle(1)
            .setMinLength(0)
            .setMaxLength(7)
            .setPlaceholder(`#0098ff`)
            .setValue(`#0098ff`);

        const image = new Discord.TextInputBuilder()
            .setCustomId(`embedgenerator-image`)
            .setLabel(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].embedGeneratorImage }`)
            .setStyle(1)
            .setMinLength(0)
            .setMaxLength(1000)
            .setRequired(false)
            .setPlaceholder(`https://i.imgur.com/...`);

        const titleActionRow = new Discord.ActionRowBuilder()
            .addComponents([title]);
        const descriptionActionRow = new Discord.ActionRowBuilder()
            .addComponents([description]);
        const urlActionRow = new Discord.ActionRowBuilder()
            .addComponents([url]);
        const colorActionRow = new Discord.ActionRowBuilder()
            .addComponents([color]);
        const imageActionRow = new Discord.ActionRowBuilder()
            .addComponents([image]);

        modal.addComponents(titleActionRow, descriptionActionRow, urlActionRow, colorActionRow, imageActionRow);

        interaction.showModal(modal);
    },

    /**
     * @param {Discord.Interaction} interaction The interaction object.
     * @param {string} channelId The channel ID to send the embed to.
     * @param {Discord} Discord The Discord Object.
     * @param {Discord.client} client The client object.
     */
    async handleEmbedGeneratorModal(interaction, channelId, Discord, client)
    {
        // Grab data they submitted
        const [title] = [`embedgenerator-title`]
            .map((id) => interaction.fields.getTextInputValue(id));
        const [description] = [`embedgenerator-description`]
            .map((id) => interaction.fields.getTextInputValue(id));
        const [url] = [`embedgenerator-url`]
            .map((id) => interaction.fields.getTextInputValue(id));
        let [color] = [`embedgenerator-color`]
            .map((id) => interaction.fields.getTextInputValue(id));
        if (!color.startsWith(`#`) && color.length > 0)
            color = `#${ color }`;
        else if (color.length === 0)
            color = `#0098ff`;
        const [image] = [`embedgenerator-image`]
            .map((id) => interaction.fields.getTextInputValue(id));

        // Construct the embed
        const embed = new Discord.EmbedBuilder()
            .setTitle(title.trim())
            .setDescription(description.trim())
            .setColor(color);

        if (url.length > 0)
            embed.setURL(url);

        if (image.length > 0)
            embed.setImage(image);

        let channel;
        if (!channelId)
            channel = interaction.channel;
        channel = await client.channels.fetch(channelId).catch(() => interaction.channel);

        channel.send({ embeds: [embed] }).then(() =>
        {
            interaction.message.delete(); // Delete the generator button
            interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
        })
            .catch((error) =>
            {
                interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].somethingWentWrong }\n\`\`\`${ error }\`\`\``);
            });
    }
};
