import SQLite from "better-sqlite3";
import { ButtonStyle } from "discord.js";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);
reactionMessageIds = global.reactionMessageIds;

export default {
    respond
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} response The response to send.
 * @param {string} moderatorId The ID of the moderator.
 * @param {string} messageID The ID of the message.
 * @param {*} Discord The Discord Object.
 */
export async function respond(interactionOrMessage, isSlashCommand, response, moderatorId, messageID, Discord)
{
    const guildId = interactionOrMessage.guild.id;
    const { regionalChannelID } = common.getGuildConfig(guildId);

    let responseObject = sql.prepare(`SELECT * FROM keywords WHERE guildId = ${ guildId }`).raw().all();

    if (regionalChannelID && interactionOrMessage.channel.id === regionalChannelID)
        responseObject = sql.prepare(`SELECT * FROM keywordsRegional WHERE guildId = ${ guildId }`).raw().all();

    for (const element of responseObject)
    {
        if (response.toLowerCase().includes(element[1]))
        {
            var deleteButton = new Discord.ButtonBuilder()
                .setStyle(ButtonStyle.Danger)
                .setLabel(`Delete`)
                .setDisabled(false)
                .setCustomId(moderatorId);

            const button = new Discord.ActionRowBuilder().addComponents(deleteButton);

            if (messageID)
            {
                interactionOrMessage.channel.messages.fetch(messageID).then((message) =>
                {
                    message.reply({
                        content: element[2],
                        components: [button]
                    }).then((message) =>
                    {
                        reactionMessageIds.push(message.id); // remember message ID because we react to it
                    });
                });
            }
            else
            {
                interactionOrMessage.channel.send({
                    content: element[2],
                    components: [button]
                })
                    .then((message) =>
                    {
                        reactionMessageIds.push(message.id);
                    });
            }
            if (isSlashCommand)
                interactionOrMessage.followUp(`${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].interactionBasicSuccess }`);
            return;
        }
    }

    common.sendInteractionOrMessage(interactionOrMessage, {
        content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].triggerDoesNotExist
    }, isSlashCommand);
}
