import { createRequire } from "node:module";
import common from "../../../utils/common.js";

const require = createRequire(import.meta.url);
const { token } = require(`../../../config.json`);

export default {
    getAVI
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {*} member The member object.
 */
export async function getAVI(interactionOrMessage, isSlashCommand, member)
{
    let hasBanner = false;
    let hasGuildAVI = false;
    let hasGuildBanner = false;
    const avatar = member.displayAvatarURL({ dynamic: true, size: 4096 });
    let banner = member.banner;
    if (banner)
    {
        hasBanner = true;
        banner = member.bannerURL({ dynamic: true, size: 4096 });
    }

    let string = ``;
    string += `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].avatar }: ${ avatar }\n`;

    // also get the persons server avatar if they have one set
    const data = await common.fetchJsonResponse(
        `https://discord.com/api/guilds/${ interactionOrMessage.guild.id }/members/${ member.id }`,
        {
            method: `GET`,
            headers: {
                Authorization: `Bot ${ token }`
            }
        }
    );
    if (!data)
    {
        return common.sendInteractionOrMessage(interactionOrMessage, {
            content: string
        }, isSlashCommand);
    }

    if (data.avatar)
        hasGuildAVI = true;
    if (data.banner)
        hasGuildBanner = true;

    if (hasBanner)
        string += `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].banner }: ${ banner }\n`;
    if (hasGuildAVI)
    {
        let guildAVI = data.avatar;
        guildAVI = guildAVI.startsWith(`a_`) ? `https://cdn.discordapp.com/guilds/${ interactionOrMessage.guild.id }/users/${ member.id }/avatars/${ guildAVI }.gif?size=4096` : `https://cdn.discordapp.com/guilds/${ interactionOrMessage.guild.id }/users/${ member.id }/avatars/${ guildAVI }.png?size=4096`;
        string += `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].server } ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].avatar }: ${ guildAVI }\n`;
    }
    if (hasGuildBanner)
    {
        let guildBanner = data.banner;
        guildBanner = guildBanner.startsWith(`a_`) ? `https://cdn.discordapp.com/guilds/${ interactionOrMessage.guild.id }/users/${ member.id }/avatars/${ guildBanner }.gif?size=4096` : `https://cdn.discordapp.com/guilds/${ interactionOrMessage.guild.id }/users/${ member.id }/avatars/${ guildBanner }.png?size=4096`;
        string += `${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].server } ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].banner }: ${ guildBanner }\n`;
    }

    common.sendInteractionOrMessage(interactionOrMessage, {
        content: string
    }, isSlashCommand);
}
