import Discord, { ButtonStyle } from "discord.js";
import https from "node:https";
import common from "../../../utils/common.js";

const mw2SaleIds = [];

export default {
    /**
     * @param {string} channelID The ID of the channel to send the message to.
     * @param {*} client The Discord Client Object.
     * @param {boolean} isAutomated Whether or not this is an automated check.
     */
    checkSteamMW2Sale(channelID, client, isAutomated)
    {
        const guildId = client.channels.cache.get(channelID).guild.id;
        const { ITADAPIKey } = common.getGuildConfig(guildId);
        // If either the ITADAPIKey is not set (or empty), or the channelID is not set (or empty), return.
        if (!ITADAPIKey
            || ITADAPIKey.length === 0
            || !channelID
            || channelID.length === 0)
            return; // They dont have things setup; however we cant reply since this can be automated.

        const url = `https://api.isthereanydeal.com/v01/game/prices/?key=${ ITADAPIKey }&plains=callofdutymodernwarfareii2009&country=US`;
        let data = ``;

        https.get(url, (resp) =>
        {
            resp.on(`data`, (chunk) =>
            {
                data += chunk;
            });

            resp.on(`end`, () =>
            {
                data = JSON.parse(data);
                if (data.error) return;
                const saleInfo = data.data.callofdutymodernwarfareii2009.list[0]; // 0 is the first item in the list (Cheapest Source).
                const channelToSend = client.channels.cache.get(channelID);
                if (!channelToSend) // This channel doesn't exist? Invalid generalChannelID?
                    return;

                const button = new Discord.ActionRowBuilder().addComponents(
                    new Discord.ButtonBuilder()
                        .setStyle(ButtonStyle.Danger)
                        .setLabel(`${ global.locale[global.findLocale(channelToSend.guild.id)].delete }`)
                        .setDisabled(false)
                        .setCustomId(`MW2_STEAM_SALE`)
                );

                if (saleInfo.price_new < saleInfo.price_old)
                {
                    channelToSend.send({
                        content: `${ global.locale[global.findLocale(channelToSend.guild.id)].mw2SaleMessage.replaceAll(`%saleInfo.url%`, `${ saleInfo.url }`).replaceAll(`%saleInfo.price_new%`, `${ saleInfo.price_new }`).replaceAll(`%saleInfo.price_cut%`, `${ saleInfo.price_cut }`) }`,
                        components: [button]
                    })
                        .then((message) =>
                        {
                            mw2SaleIds.push(message.id);
                        });
                }
                else if (!isAutomated)
                {
                    channelToSend.send({
                        content: `${ global.locale[global.findLocale(channelToSend.guild.id)].mw2IsNotOnSale }`,
                        components: [button]
                    })
                        .then((message) =>
                        {
                            mw2SaleIds.push(message.id);
                        });
                }
            });
        });
    },
    mw2SaleIds
};
