import common from "../../../utils/common.js";

export default {
    say
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} message The message to send.
 * @param {number} messageID The ID of the message.
 */
export async function say(interactionOrMessage, isSlashCommand, message, messageID)
{
    var regex = /(?:https?:\/\/)?[\w%./=?-]+\.(?:jpe?g|png|gif|tiff?)/gi;
    const interactionChannel = interactionOrMessage.channel;
    var matches = message.match(regex);
    if (messageID)
    {
        const messageToReplyTo = await interactionChannel.messages.fetch(messageID);
        if (messageToReplyTo)
        {
            if (matches)
            { // If we have images
                if (matches.length <= 10)
                { // If we have <= 10 images
                    const messageWithoutMatches = message.replace(regex, ``); // Remove the matches from the message
                    if (messageWithoutMatches === ``)
                    {
                        messageToReplyTo.reply({
                            files: matches
                        });
                    }
                    else
                    { // Message Content w/ Images
                        if (messageWithoutMatches.length > 2000)
                        {
                            return common.sendInteractionOrMessage(interactionOrMessage, {
                                content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].messageTooLong
                            }, isSlashCommand);
                        }
                        messageToReplyTo.reply({
                            files: matches,
                            content: messageWithoutMatches
                        });
                    }
                }
            }
            else
            {
                if (message.length > 2000)
                {
                    return common.sendInteractionOrMessage(interactionOrMessage, {
                        content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].messageTooLong
                    }, isSlashCommand);
                }
                messageToReplyTo.reply(message); // Send the message if there are no images
            }
        }
    }
    // Sending a message without a messageID
    else if (matches)
    { // If we have images
        if (matches.length <= 10)
        { // If we have <= 10 images
            const messageWithoutMatches = message.replace(regex, ``); // Remove the matches from the message
            if (messageWithoutMatches === ``)
            {
                interactionChannel.send({
                    files: matches
                });
            }
            else
            { // Message Content w/ Images
                if (messageWithoutMatches.length > 2000)
                {
                    return common.sendInteractionOrMessage(interactionOrMessage, {
                        content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].messageTooLong
                    }, isSlashCommand);
                }
                interactionChannel.send({
                    files: matches,
                    content: messageWithoutMatches
                });
            }
        }
    }
    else
    {
        if (message.length > 2000)
        {
            return common.sendInteractionOrMessage(interactionOrMessage, {
                content: global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].messageTooLong
            }, isSlashCommand);
        }
        interactionChannel.send(message); // Send the message if there are no images
    }
}
