import { createRequire } from "node:module";
import common from "../../../utils/common.js";

import logging from "../../../utils/logging.js";

const require = createRequire(import.meta.url);
const { botOwnerID } = require(`../../../config.json`);

export default {
    sendDm
};

/**
 * @param {*} interactionOrMessage The interaction or message object.
 * @param {boolean} isSlashCommand Whether or not the interaction is a slash command.
 * @param {string} messageToSend The message to send.
 * @param {Discord.GuildMember} guildMember The guild member object.
 * @param {*} Discord The Discord Object.
 * @param {*} client The Discord Client Object.
 */
export async function sendDm(interactionOrMessage, isSlashCommand, messageToSend, guildMember, Discord, client)
{
    guildMember.send(messageToSend).catch(() => logging.warn(`Could not DM, ignoring`));
    let title;
    title = isSlashCommand ? `${ interactionOrMessage.user.tag } (${ interactionOrMessage.user.id }) ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].sentDMTo } ${ guildMember.tag } (${ guildMember.id })` : `${ interactionOrMessage.author.tag } (${ interactionOrMessage.author.id }) ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].sentDMTo } ${ guildMember.tag } (${ guildMember.id })`;
    title = common.truncateString(title, 256);

    const embed = new Discord.EmbedBuilder()
        .setColor(`#ff0000`)
        .setTitle(`${ title }`)
        .setDescription(`${ messageToSend }`);
    for (const ownerID of botOwnerID)
    {
        const owner = await client.users.fetch(ownerID);
        if (owner)
        {
            var attachmentsArray = [];
            if (!isSlashCommand && interactionOrMessage.attachments.size > 0)
            {
                for (const attachment of interactionOrMessage.attachments.values())
                    attachmentsArray.push(attachment.url);
                let attachContent = `<@!${ interactionOrMessage.author.id }> (${ interactionOrMessage.author.id }) ${ global.locale[global.findLocale(interactionOrMessage.guild.id, interactionOrMessage.locale)].sentDMTo } ${ guildMember.tag } (${ guildMember.id })\n${ attachmentsArray.join(`, `) }`;
                attachContent = common.truncateString(attachContent, 1024);
                owner.send({ content: `${ attachContent }` }, { files: attachmentsArray });
            }
            owner.send({ embeds: [embed] });
        }
    }
}
