import { ApplicationCommandOptionType } from "discord.js";
import common from "../../../../utils/common.js";

export default {
    name: `broadcast`,
    description: `Sends a message to every guild's auditChannel. Use \\n to add a new line.`,
    type: ApplicationCommandOptionType.Subcommand,
    options: [
        {
            name: `message`,
            description: `Which message to broadcast`,
            type: ApplicationCommandOptionType.String,
            required: true
        }
    ],

    async callback(interaction, client)
    {
        let message = interaction.options.getString(`message`);
        if (message.length > 2000)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].messageTooLong }`);
        message = message.replace(/\\n/g, `\n`);

        const guilds = client.guilds.cache.map((guild) => guild.id);
        for (const guildId of guilds)
        {
            const guild = client.guilds.cache.get(guildId);
            const { auditChannelID } = common.getGuildConfig(guildId);

            if (auditChannelID)
            {
                const auditChannel = guild.channels.cache.get(auditChannelID);
                if (auditChannel)
                    auditChannel.send(message);
            }
        }
        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].broadcastSuccess.replaceAll(`%count%`, `${ guilds.length }`) }`);
    }
};
