import { ApplicationCommandOptionType, ChannelType } from "discord.js";

export default {
    name: `generateinvite`,
    description: `Generates an invite link for a Guild ID.`,
    type: ApplicationCommandOptionType.Subcommand,
    options: [
        {
            name: `guildid`,
            description: `Guild ID of server to generate an invite for.`,
            type: ApplicationCommandOptionType.String,
            required: true
        }
    ],

    async callback(interaction, client)
    {
        const guildid = interaction.options.getString(`guildid`);

        const guild = client.guilds.cache.get(guildid);
        if (!guild)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noGuild.replaceAll(`%ourArgs%`, `${ guildid }`) }`);

        // Find the first channel & make an invite link
        const channel = guild.channels.cache.find((c) => c.type === ChannelType.GuildText);
        if (!channel)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noTextChan.replaceAll(`%guildName%`, `${ guild.name }`) }`);

        const invite = await channel.createInvite({
            maxAge: 0,
            maxUses: 0
        }).catch(() => interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noInvite.replaceAll(`%guildName%`, `${ guild.name }`) }`));

        return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].inviteMade.replaceAll(`%guildName%`, `${ guild.name }`).replaceAll(`%invite%`, `${ invite.url }`) }`);
    }
};
