import { createRequire } from "node:module";
import { ApplicationCommandOptionType } from "discord.js";
import common from "../../../utils/common.js";
import { clearWarns } from "../../commands/moderation/clearwarns.js";

const require = createRequire(import.meta.url);
const { botOwnerID } = require(`../../../config.json`);

export default {
    name: `clearwarns`,
    description: `Clear warn history for a user.`,
    defaultMemberPermissions: [`KickMembers`],
    options: [
        {
            name: `user`,
            description: `Clear warn history of which user? NOTE: This can also be an ID`,
            type: ApplicationCommandOptionType.User,
            required: true,
        },
        {
            name: `reason`,
            description: `Which reason`,
            type: ApplicationCommandOptionType.String,
            required: false,
        }
    ],

    async execute(interaction, client, Discord)
    {
        await interaction.deferReply({ ephemeral: true });

        if (!botOwnerID.includes(interaction.user.id)) // dev only
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noPermission }`);

        const user = interaction.options.getUser(`user`);

        const member = await client.users.fetch(user.id)
            .catch(() => interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noId }`));

        let reason = interaction.options.getString(`reason`);
        if (!reason)
            reason = `${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noReasonSpecified }`;
        reason = common.truncateString(reason, 256);

        await clearWarns(client, Discord, interaction.guild.id, user.id, member, interaction.user.id, reason);

        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
    }
};
