import SQLite from "better-sqlite3";
import { ApplicationCommandOptionType } from "discord.js";
import common from "../../../utils/common.js";
import mute from "../../commands/moderation/mute.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    name: `mute`,
    description: `Mutes a user`,
    defaultMemberPermissions: [`KickMembers`],
    options: [
        {
            name: `user`,
            description: `User to mute. NOTE: This can also be an ID`,
            type: ApplicationCommandOptionType.User,
            required: true
        },
        {
            name: `duration`,
            description: `Duration? (can be 1d or 1h30m. valid times: y, mo, w, d, h, m, s)`,
            type: ApplicationCommandOptionType.String,
            required: false
        },
        {
            name: `reason`,
            description: `Reason for the mute`,
            type: ApplicationCommandOptionType.String,
            required: false
        },
    ],

    async execute(interaction, client, Discord)
    {
        await interaction.deferReply({ ephemeral: true });

        const guildId = interaction.guild.id;
        const { mutedRoleID } = common.getGuildConfig(guildId);

        const duration = interaction.options.getString(`duration`);
        const user = interaction.options.getUser(`user`);

        if ((!mutedRoleID)
            || mutedRoleID.length < 10)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noMuteRole }`);

        const role = interaction.guild.roles.cache.get(mutedRoleID);
        if (!role)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noMuteRole }`);

        const guild = client.guilds.cache.get(interaction.guild.id);
        const member = await common.getGuildMember(client, interaction.guild.id, user.id);

        if (member && member.roles.highest.position >= interaction.member.roles.highest.position && guild.ownerId !== interaction.user.id) return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].cantMute }`);

        let reason = interaction.options.getString(`reason`);
        if (!reason)
            reason = `${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noReasonSpecified }`;
        reason = common.truncateString(reason, 256);
        let time = 0;
        var isExtending = false;

        if (duration)
        { // Did they specify a duration?
            time = await common.getEpoch(duration, false);
            if (time === -1337)
                return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].badTimeUnit }`);

            const row = sql.prepare(`SELECT * FROM mutes WHERE guildId = ? AND userId = ?`).get(interaction.guild.id, user.id);
            if (row && row.time > 1)
            { // If they are already muted, and have a punishment, take their current mute time and add the new time to it.
                isExtending = true;
                time = Number.parseInt(row.time, 10) + time;
                await mute.sendMuteToDB(client, interaction.guild.id, interaction.user.id, user.id, time, reason, duration);
            }
            else if (row && row.time < 1)
                return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].permMute }`);
            else if (member && member.roles.cache.some((r) => r.id === mutedRoleID)) // If they are muted, but do not have a punishment (i.e. a manual mute), assume the manual mute is what we want.
                return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].manualMute }`);
            else
            { // fresh temp mute
                await mute.sendMuteToDB(client, interaction.guild.id, interaction.user.id, user.id, Date.now() + time, reason, duration);
            }
        }
        else
        { // fresh perma mute
            time = -1;
            await mute.sendMuteToDB(client, interaction.guild.id, interaction.user.id, user.id, time, reason);
        }

        const authorTag = interaction.user.tag;

        // Boot them from VC
        if (member && member.voice)
            member.voice.disconnect();

        mute.handleMute(Discord, client, member, interaction.user.id, role, authorTag, reason, time, isExtending, interaction.guild.id, user.id); // handles rest of mute process
        interaction.followUp(`${ user } ${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].hasBeenMuted }`);
    }
};
