import SQLite from "better-sqlite3";
import { ApplicationCommandOptionType } from "discord.js";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    name: `rolepersist`,
    description: `Ensures a role sticks to a user even if they leave and come back.`,
    defaultMemberPermissions: [`ManageRoles`],
    options: [
        {
            name: `addorremove`,
            description: `Add or remove the role?`,
            type: ApplicationCommandOptionType.String,
            choices: [
                {
                    name: `Add`,
                    value: `add`
                },
                {
                    name: `Remove`,
                    value: `remove`
                }
            ],
            required: true,
        },
        {
            name: `user`,
            description: `Which user?`,
            type: ApplicationCommandOptionType.User,
            required: true
        },
        {
            name: `role`,
            description: `Which Role?`,
            type: ApplicationCommandOptionType.Role,
            required: true
        },
    ],

    async execute(interaction, client)
    {
        await interaction.deferReply({ ephemeral: true });

        const addorremove = interaction.options.getString(`addorremove`);
        if (addorremove === `add`)
            var isAddingRole = true;
        else
            var isAddingRole = false;
        let user = interaction.options.getUser(`user`);
        user = await common.getGuildMember(client, interaction.guild.id, user.id, true);
        const role = interaction.options.getRole(`role`);
        const roleId = role.id;

        if (isAddingRole && !user.roles.cache.has(roleId)) user.roles.add(roleId);
        if (!isAddingRole && user.roles.cache.has(roleId)) user.roles.remove(roleId);

        const inDatabase = sql.prepare(`SELECT * FROM rolePersists WHERE guildId = ? AND userId = ?`).get(interaction.guild.id, user.id);
        if (inDatabase)
        {
            const roleArray = JSON.parse(inDatabase.roleArray);
            if (isAddingRole)
            {
                if (!roleArray.includes(roleId))
                    roleArray.push(roleId);
            }
            else if (!isAddingRole && roleArray.includes(roleId)) roleArray.splice(roleArray.indexOf(roleId), 1);
            sql.prepare(`UPDATE rolePersists SET roleArray = ? WHERE guildId = ? AND userId = ?`).run(JSON.stringify(roleArray), interaction.guild.id, user.id);
            if (roleArray.length === 0)
                sql.prepare(`DELETE FROM rolePersists WHERE guildId = ? AND userId = ?`).run(interaction.guild.id, user.id);
        }
        else
            sql.prepare(`INSERT INTO rolePersists (guildId, userId, roleArray) VALUES (?, ?, ?)`).run(interaction.guild.id, user.id, JSON.stringify([roleId]));

        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
    }
};
