import { ApplicationCommandOptionType } from "discord.js";
import unmute from "../../commands/moderation/unmute.js";
import common from "../../../utils/common.js";

export default {
    name: `unmute`,
    description: `Unmutes a user`,
    defaultMemberPermissions: [`ManageRoles`],
    options: [
        {
            name: `user`,
            description: `Which user to unmute. NOTE: This can also be an ID`,
            type: ApplicationCommandOptionType.User,
            required: true
        },
        {
            name: `reason`,
            description: `For which reason`,
            type: ApplicationCommandOptionType.String,
            required: false
        },
    ],

    async execute(interaction, client, Discord)
    {
        await interaction.deferReply({ ephemeral: true });

        const guildId = interaction.guild.id;
        const { mutedRoleID } = common.getGuildConfig(guildId);

        const user = interaction.options.getUser(`user`);

        if ((!mutedRoleID)
            || mutedRoleID.length < 10)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].noMuteRole }`);

        const mutedRole = interaction.guild.roles.cache.get(mutedRoleID);
        if (!mutedRole)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].badMuteRole }`);

        const reason = interaction.options.getString(`reason`);
        unmute.unmute(interaction, true, user.id, interaction.user.id, reason, client, Discord);
        interaction.followUp(`<@!${ user.id }> ${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].hasBeenUnmuted }`);
    }
};
