import { ChannelType } from "discord.js";
import common from "../../../utils/common.js";
import utils from "../../../webfront/utils.js";

export default {
    name: `bootstrap`,
    description: `Sets up a server with sane defaults and creates required roles.`,
    defaultMemberPermissions: [`Administrator`],
    options: [],

    async execute(interaction)
    {
        const guildId = interaction.guild.id;
        const guild = interaction.guild;

        const { auditChannelID, deletedMessagesChanID } = common.getGuildConfig(guildId);

        let {
            vipRoleID, mutedRoleID, noPingRoleId, generalChannelID
        } = common.getGuildConfig(guildId);

        // Get the @\everyone role
        const everyoneRole = await interaction.guild.roles.cache.find((role) => role.id === interaction.guild.id);

        // Set default notifications to only mentions
        await interaction.guild.edit({
            defaultMessageNotifications: `ONLY_MENTIONS`,
        });

        const defaultPermissions = everyoneRole.permissions.toArray();
        // Remove "MENTION_EVERYONE" from the default permissions
        if (defaultPermissions.includes(`MENTION_EVERYONE`))
            defaultPermissions.splice(defaultPermissions.indexOf(`MENTION_EVERYONE`), 1);

        // Update the @\everyone role to have the default permissions
        await everyoneRole.edit({
            permissions: defaultPermissions,
        });

        if (vipRoleID === ``)
        {
            // Create the VIP role
            const vipRole = await interaction.guild.roles.create({
                name: `VIP`,
                color: `BLUE`,
                hoist: false,
                mentionable: false,
                permissions: defaultPermissions
            });
            // Save the role id
            vipRoleID = vipRole.id;
            // Save the role id to the guild config
            utils.saveGuildConfigValue(guild, `vipRoleID`, vipRoleID);
        }

        if (mutedRoleID === ``)
        {
            // Create the muted role
            const mutedRole = await interaction.guild.roles.create({
                name: `Muted`,
                color: `GREY`,
                hoist: false,
                mentionable: false,
            });
            mutedRole.setPermissions([`ViewChannel`]);
            // Save the role id
            mutedRoleID = mutedRole.id;
            // Save the role id to the guild config
            utils.saveGuildConfigValue(guild, `mutedRoleID`, mutedRoleID);
        }

        if (noPingRoleId === ``)
        {
            // Create the no ping role
            const noPingRole = await interaction.guild.roles.create({
                name: `No Mentions`,
                color: `GREY`,
                hoist: false,
                mentionable: false,
                permissions: defaultPermissions,
            });
            // Save the role id
            noPingRoleId = noPingRole.id;
            // Save the role id to the guild config
            utils.saveGuildConfigValue(guild, `noPingRoleId`, noPingRoleId);
        }

        if (deletedMessagesChanID === `` && auditChannelID !== ``)
            utils.saveGuildConfigValue(guild, `deletedMessagesChanID`, auditChannelID);

        if (generalChannelID === ``)
        {
            // Look for a channel called "general"
            try
            {
                var generalChannel = interaction.guild.channels.cache.find((channel) => channel.name.toLowerCase() === `general`);
            }
            catch
            {
                var generalChannel = await interaction.guild.channels.create({
                    name: `general`,
                    type: ChannelType.GuildText,
                    permissionOverwrites: defaultPermissions,
                });
            }
            // Save the channel id
            generalChannelID = generalChannel.id;
            // Save the channel id to the guild config
            utils.saveGuildConfigValue(guild, `generalChannelID`, generalChannelID);
        }

        utils.saveGuildConfigValue(guild, `autoBanMode`, `link`);
        utils.saveGuildConfigValue(guild, `renameUntaggableNames`, true);

        // Update every channel to prevent Muted role from typing or reacting
        const channels = await interaction.guild.channels.cache.values();
        for (const channel of channels)
        {
            await channel.permissionOverwrites.edit(mutedRoleID, {
                SendMessages: false,
                AddReactions: false,
                Connect: false,
                Speak: false,
            });
        }

        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
    }
};
