import { ApplicationCommandOptionType, ChannelType } from "discord.js";

export default {
    name: `createforumpost`,
    description: `Create a new forum post.`,
    defaultMemberPermissions: [`KickMembers`],
    options: [
        {
            name: `channel`,
            description: `Where do you want to create the forum post?`,
            type: ApplicationCommandOptionType.Channel,
            channelTypes: [ChannelType.GuildForum],
            required: true
        },
        {
            name: `title`,
            description: `What is the title of the forum post?`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
        {
            name: `message`,
            description: `What is the message of the forum post? Use \\n for new lines.`,
            type: ApplicationCommandOptionType.String,
            required: true
        }
    ],

    async execute(interaction)
    {
        await interaction.deferReply({ ephemeral: true });

        const channel = interaction.options.getChannel(`channel`);
        let title = interaction.options.getString(`title`);
        let message = interaction.options.getString(`message`);
        message = message.replace(/\\n/g, `\n`);

        if (title.length > 100)
            title = title.slice(0, 100);

        if (message.length > 2000)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].messageTooLong }`);

        // TODO: Dynamically get tags (as a command option?)
        // https://discord.js.org/#/docs/discord.js/main/class/ForumChannel?scrollTo=availableTags
        let fail = false;
        const thread = await channel.threads.create({ name: title, message: { content: message }, tags: [] }).catch(
            (error) =>
            {
                // TODO: Localize this.
                if (error.toString().includes(`A tag is required to create a forum post in this channel`))
                    interaction.followUp(`Please disable \`Require people to select tags when posting\` in this channel.\nWe will eventually add support for this.`);
                else
                    interaction.followUp(`\`${ error }\``);
                fail = true;
            }
        );
        if (!fail) interaction.followUp(`<#${ thread.id }>`);
    }
};
