import SQLite from "better-sqlite3";
import { ApplicationCommandOptionType } from "discord.js";
import common from "../../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    name: `edit`,
    description: `Edit an existing giveaway.`,
    type: ApplicationCommandOptionType.Subcommand,
    options: [
        {
            name: `messageid`,
            description: `The message ID of the giveaway to edit.`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
        {
            name: `item`,
            description: `What item should we give away? For newlines, use \\n.`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
        {
            name: `amount`,
            description: `How many winners?`,
            type: ApplicationCommandOptionType.Number,
            /* eslint-disable camelcase */
            min_value: 1,
            max_value: 100,
            /* eslint-enable camelcase */
            required: true
        },
        {
            name: `time`,
            description: `How long should the giveaway last from now? (can be 1d or 1h30m. valid times: y, mo, w, d, h, m, s)`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
    ],

    async callback(interaction, client)
    {
        const messageid = interaction.options.getString(`messageid`);
        const item = interaction.options.getString(`item`).replace(/\\n/g, `\n`);
        const amount = interaction.options.getNumber(`amount`);
        const duration = interaction.options.getString(`time`);
        const time = await common.getEpoch(duration, true);
        if (time === -1337)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].badTimeUnit }`);

        // Send Message
        const giveawayMeta = await sql.prepare(`SELECT * FROM giveaways WHERE messageid = ?`).get(messageid);
        if (!giveawayMeta)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].cantFindGiveaway }`);
        let message = ``;
        message += `${ global.locale[global.findLocale(interaction.guild.id)].giveawayHasBeenStarted }\n\n**${ item }** ${ global.locale[global.findLocale(interaction.guild.id)].itemWillBeGivenAway }\n\n`;
        message += `**${ amount }** ${ global.locale[global.findLocale(interaction.guild.id)].winnersWillBeSelected }\n\n`;
        message += `${ global.locale[global.findLocale(interaction.guild.id)].giveawayWillEnd } <t:${ Math.round(time / 1000) }> (<t:${ Math.round(time / 1000) }:R>)!`;
        const messageObject = await client.channels.cache.get(giveawayMeta.channelId).messages.fetch(messageid);

        await messageObject.edit({ content: message })
            .then(async () =>
            {
                sql.prepare(`UPDATE giveaways SET amountOfWinners = ?, time = ? WHERE messageid = ?`).run(amount, time, messageid);
            });

        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
    }
};
