import SQLite from "better-sqlite3";
import { ApplicationCommandOptionType, ButtonStyle, ChannelType } from "discord.js";
import common from "../../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    name: `start`,
    description: `Run a giveaway!`,
    type: ApplicationCommandOptionType.Subcommand,
    options: [
        {
            name: `item`,
            description: `What item should we give away? For newlines, use \\n.`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
        {
            name: `amount`,
            description: `How many winners?`,
            type: ApplicationCommandOptionType.Number,
            /* eslint-disable camelcase */
            min_value: 1,
            max_value: 100,
            /* eslint-enable camelcase */
            required: true
        },
        {
            name: `time`,
            description: `How long should the giveaway last? (can be 1d or 1h30m. valid times: y, mo, w, d, h, m, s)`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
        {
            name: `channel`,
            description: `Where should we post the announcement?`,
            type: ApplicationCommandOptionType.Channel,
            channelTypes: [ChannelType.GuildText],
            required: true
        },
        {
            name: `role`,
            description: `Want to mention a role?`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
    ],

    async callback(interaction, client, Discord)
    {
        const item = interaction.options.getString(`item`).replace(/\\n/g, `\n`);
        const amount = interaction.options.getNumber(`amount`);
        const duration = interaction.options.getString(`time`);
        const time = await common.getEpoch(duration, true);
        if (time === -1337)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].badTimeUnit }`);

        // Send Message
        const channel = interaction.options.getChannel(`channel`);
        const role = interaction.options.getRole(`role`);
        let message = ``;
        if (role)
            message += `||<@&${ role.id }>||\n`;
        message += `${ global.locale[global.findLocale(interaction.guild.id)].giveawayHasBeenStarted }\n\n**${ item }** ${ global.locale[global.findLocale(interaction.guild.id)].itemWillBeGivenAway }\n\n`;
        message += `**${ amount }** ${ global.locale[global.findLocale(interaction.guild.id)].winnersWillBeSelected }\n\n`;
        message += `${ global.locale[global.findLocale(interaction.guild.id)].giveawayWillEnd } <t:${ Math.round(time / 1000) }> (<t:${ Math.round(time / 1000) }:R>)!`;
        // Create a button to open the ticket
        const button = new Discord.ButtonBuilder()
            .setCustomId(`entergiveaway`)
            .setLabel(`${ global.locale[global.findLocale(interaction.guild.id)].giveawayEnter }`)
            .setStyle(ButtonStyle.Success)
            .setDisabled(false);
        const buttonArray = [button];
        const row = new Discord.ActionRowBuilder()
            .addComponents(buttonArray);
        await channel.send({ content: message, components: [row] })
            .then(async (message) =>
            {
                sql.prepare(`INSERT INTO giveaways (guildId, messageId, time, amountOfWinners, channelId) VALUES (?, ?, ?, ?, ?)`).run(interaction.guild.id, message.id, time, amount, channel.id);
            });

        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
    }
};
