import SQLite from "better-sqlite3";
import { ApplicationCommandOptionType } from "discord.js";
import common from "../../../utils/common.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    name: `remindme`,
    description: `Reminds you of something.`,
    defaultMemberPermissions: [`KickMembers`],
    options: [
        {
            name: `time`,
            description: `When to remind you? (can be 1d or 1h30m. valid times: y, mo, w, d, h, m, s)`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
        {
            name: `message`,
            description: `What do you want me to remind you of?`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
    ],

    async execute(interaction, client, Discord)
    {
        await interaction.deferReply({ ephemeral: true });

        const Time = interaction.options.getString(`time`);
        const message = interaction.options.getString(`message`);

        if (message.length > 2000)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].messageTooLong }`);

        const time = await common.getEpoch(Time, true);
        if (time === -1337)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].badTimeUnit }`);

        // insert into db
        sql.prepare(`INSERT INTO scheduledmessages (guildId, channelId, time, content) VALUES (?, ?, ?, ?)`).run(interaction.guild.id, interaction.channel.id, time, `<@!${ interaction.user.id }>, ${ message }`);
        const embed = new Discord.EmbedBuilder()
            .setColor(`#00ff00`)
            .setTimestamp()
            .setAuthor({ name: `${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].reminderScheduled }` })
            .setDescription(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].reminderDescription.replaceAll(`%messageAuthorUsername%`, `${ interaction.user.username }`) } <t:${ Math.round(time / 1000) }:R> ${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].reminderDescription2.replaceAll(`%messageToSend%`, `${ message }`) }`);
        interaction.followUp({ embeds: [embed] });
    }
};
