import SQLite from "better-sqlite3";
import { ApplicationCommandOptionType, ChannelType } from "discord.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    name: `schedule`,
    description: `Schedules messages to be sent.`,
    defaultMemberPermissions: [`KickMembers`],
    options: [
        {
            name: `time`,
            description: `Timestamp in Epoch ms. See /help epoch for more info.`,
            type: ApplicationCommandOptionType.Number,
            required: true
        },
        {
            name: `channel`,
            description: `Which channel`,
            type: ApplicationCommandOptionType.Channel,
            channelTypes: [ChannelType.GuildText],
            required: true
        },
        {
            name: `message`,
            description: `Which message`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
    ],

    async execute(interaction, client, Discord)
    {
        await interaction.deferReply({ ephemeral: true });

        const time = interaction.options.getNumber(`time`);
        const channel = interaction.options.getChannel(`channel`);
        const message = interaction.options.getString(`message`);

        if (message.length > 2000)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].messageTooLong }`);

        // insert into db
        sql.prepare(`INSERT INTO scheduledmessages (guildId, channelId, time, content) VALUES (?, ?, ?, ?)`).run(interaction.guild.id, channel.id, time, message);
        const embed = new Discord.EmbedBuilder()
            .setColor(`#00ff00`)
            .setTimestamp()
            .setAuthor({ name: `${ global.locale[global.findLocale(interaction.guild.id)].messageScheduled }` })
            .addFields([{ name: `${ global.locale[global.findLocale(interaction.guild.id)].channel }`, value: `<#${ channel.id }>`, inline: true }])
            .addFields([{ name: `${ global.locale[global.findLocale(interaction.guild.id)].time }`, value: `<t:${ time / 1000 }> (<t:${ time / 1000 }:R>)`, inline: true }])
            .addFields([{ name: `${ global.locale[global.findLocale(interaction.guild.id)].message }`, value: message, inline: true }]);
        interaction.followUp({ embeds: [embed] });
    }
};
