import { ApplicationCommandOptionType, ChannelType } from "discord.js";

export default {
    name: `selectroles`,
    description: `Sends a message with opt-in roles.`,
    defaultMemberPermissions: [`Administrator`],
    options: [
        {
            name: `channel`,
            description: `Channel ID to send the message.`,
            type: ApplicationCommandOptionType.Channel,
            channelTypes: [ChannelType.GuildText],
            required: true,
        },
        {
            name: `dropdownmessage`,
            description: `What do you want the dropdown to say?`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
        {
            name: `message`,
            description: `Message Body. If you don't want any, enter ** ** here. Use \\n to make newlines.`,
            type: ApplicationCommandOptionType.String,
            required: true
        },
        {
            name: `max-amount`,
            description: `How many roles (max) do you want them to be able to select? Use 1 to let them select only one role.`,
            type: ApplicationCommandOptionType.Number,
            /* eslint-disable camelcase */
            min_value: 1,
            max_value: 20,
            /* eslint-enable camelcase */
            required: true
        },
        {
            name: `role-1`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: true
        },
        {
            name: `role-2`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-3`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-4`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-5`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-6`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-7`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-8`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-9`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-10`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-11`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-12`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-13`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-14`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-15`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-16`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-17`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-18`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-19`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
        {
            name: `role-20`,
            description: `Role to add.`,
            type: ApplicationCommandOptionType.Role,
            required: false
        },
    ],

    async execute(interaction, client, Discord)
    {
        await interaction.deferReply({ ephemeral: true });
        let dropdownmessage = interaction.options.getString(`dropdownmessage`);
        let message = interaction.options.getString(`message`);
        const channel = interaction.options.getChannel(`channel`);
        const minAmount = 0;
        const maxAmount = interaction.options.getNumber(`max-amount`);
        if (dropdownmessage.length > 150)
            dropdownmessage = dropdownmessage.slice(0, 150);
        message = message.replace(/\\n/g, `\n`);
        if (message.length > 2000)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].messageTooLong }`);

        const roleIds = [];
        const roleNames = [];
        for (let index = 1; index <= 21; index++)
        {
            const role = interaction.options.getRole(`role-${ index }`);
            if (role)
            {
                roleIds.push(role.id);
                roleNames.push(role.name);
            }
        }

        // Remove duplicates
        const uniqueRoleIds = [...new Set(roleIds)];

        if (uniqueRoleIds.length < maxAmount)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].maxRoleSelectError }`);

        const roleMenu = new Discord.SelectMenuBuilder()
            .setCustomId(`selectroles`)
            .setPlaceholder(`${ dropdownmessage }`)
            .setMinValues(minAmount)
            .setMaxValues(maxAmount);

        for (const [index, roleId] of uniqueRoleIds.entries())
            roleMenu.addOptions({ label: roleNames[index], value: roleId });

        const row = new Discord.ActionRowBuilder()
            .addComponents([roleMenu]);
        channel.send({ content: message, components: [row] });
        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
    }
};
