import { ChannelType } from "discord.js";
import common from "../../../utils/common.js";

export default {
    name: `serverstats`,
    description: `Creates a category for server stats.`,
    defaultMemberPermissions: [`Administrator`],
    options: [],

    async execute(interaction, client)
    {
        await interaction.deferReply({ ephemeral: true });

        const {
            serverStatsChanId, memberStatsChanId, boostersStatsChanId,
            serverStatsCatName, serverStatsMemberChanName, serverStatsBoosterChanName
        } = common.getGuildConfig(interaction.guild.id);

        let serverStatsChan = interaction.guild.channels.cache.find((channel) => channel.id === serverStatsChanId);
        let memberStatsChan = interaction.guild.channels.cache.find((channel) => channel.id === memberStatsChanId);
        let boostersStatsChan = interaction.guild.channels.cache.find((channel) => channel.id === boostersStatsChanId);

        if (!serverStatsChan || !memberStatsChan || !boostersStatsChan)
        {
            if (!serverStatsChan)
            {
                serverStatsChan = await interaction.guild.channels.create({
                    name: serverStatsCatName,
                    type: ChannelType.GuildCategory,
                    permissionOverwrites: [
                        { // Deny @everyone from viewing the logs channel.
                            id: interaction.guild.id,
                            allow: [`ViewChannel`],
                            deny: [`SendMessages`, `Connect`],
                        },
                        {
                            id: client.user.id,
                            allow: [`ViewChannel`, `Connect`, `ManageChannels`],
                        }
                    ],
                }).catch(() =>
                {
                    interaction.reply(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].serverStatsCatError }`);
                });
            }
            if (!memberStatsChan)
            {
                memberStatsChan = await interaction.guild.channels.create({
                    name: `${ serverStatsMemberChanName }${ interaction.guild.memberCount }`,
                    type: ChannelType.GuildVoice,
                    parent: serverStatsChan.id,
                });
            }
            if (!boostersStatsChan)
            {
                // Loop through all roles until we find the premium one
                let boosterRole;
                for (const role of interaction.guild.roles.cache.values())
                {
                    if (role.tags && role.tags.premiumSubscriberRole)
                        boosterRole = role;
                }
                // If we get through all roles & didn't find the premium one, fake one and set size to 0.
                if (!boosterRole)
                {
                    boosterRole = {
                        members: {
                            size: 0,
                        },
                    };
                }

                boostersStatsChan = await interaction.guild.channels.create({
                    name: `${ serverStatsBoosterChanName }${ boosterRole.members.size }`,
                    type: ChannelType.GuildVoice,
                    parent: serverStatsChan.id,
                });
            }
            // Save cat ID's
            const guildId = interaction.guild.id;
            const guildConfig = global.getConfiguration.get(guildId);
            const GUILD_CONFIG = JSON.parse(guildConfig.config);
            GUILD_CONFIG.serverStatsChanId = serverStatsChan.id;
            GUILD_CONFIG.memberStatsChanId = memberStatsChan.id;
            GUILD_CONFIG.boostersStatsChanId = boostersStatsChan.id;
            const data = {
                guildId,
                config: JSON.stringify(GUILD_CONFIG)
            };
            global.setConfiguration.run(data);
        }

        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
    }
};
