import { ApplicationCommandOptionType, ButtonStyle, ChannelType } from "discord.js";
import common from "../../../utils/common.js";

export default {
    name: `ticket`,
    description: `Sends a message with Open Ticket Button.`,
    defaultMemberPermissions: [`Administrator`],
    options: [
        {
            name: `channel`,
            description: `Channel ID to send the message.`,
            type: ApplicationCommandOptionType.Channel,
            channelTypes: [ChannelType.GuildText],
            required: true,
        },
        {
            name: `message`,
            description: `What do you want to accompany the ticket button? Use \\n for newlines.`,
            type: ApplicationCommandOptionType.String,
            required: true
        }
    ],

    async execute(interaction, client, Discord)
    {
        await interaction.deferReply({ ephemeral: true });

        const { bannedfromTicketsRoleId, ticketAdminRoleId } = common.getGuildConfig(interaction.guild.id);

        if (!bannedfromTicketsRoleId || !ticketAdminRoleId)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].ticketCreationNoRolesError }`);

        let message = interaction.options.getString(`message`);
        const channel = interaction.options.getChannel(`channel`);
        message = message.replace(/\\n/g, `\n`);
        if (message.length > 2000)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].messageTooLong }`);

        // Create a button to open the ticket
        const button = new Discord.ButtonBuilder()
            .setCustomId(`openticket`)
            .setLabel(`${ global.locale[global.findLocale(interaction.guild.id)].openTicket }`)
            .setStyle(ButtonStyle.Primary)
            .setDisabled(false);
        const buttonArray = [button];
        const row = new Discord.ActionRowBuilder()
            .addComponents(buttonArray);
        channel.send({ content: message, components: [row] });
        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
    }
};
