import common from "../utils/common.js";

/**
 * @name channelUpdate
 * @description Event that fires when a channel is updated.
 */
export default {
    name: `channelUpdate`,
    /**
     * @param {Discord.GuildChannel} oldChannel The channel before the update.
     * @param {Discord.GuildChannel} newChannel The channel after the update.
     * @param {*} Discord The Discord Object.
     * @param {*} client The client object.
     */
    async execute(oldChannel, newChannel, Discord, client)
    {
        const guildId = newChannel.guild.id;
        const { auditChannelID } = common.getGuildConfig(guildId);

        // Check if the channel is a text channel
        if (newChannel.type === `GUILD_TEXT` // Check if slowmode was changed
            && oldChannel.rateLimitPerUser !== newChannel.rateLimitPerUser)
        {
            await common.sleep(3000); // delay to get audit log entry
            const fetchedLogs = await newChannel.guild.fetchAuditLogs({
                limit: 1,
                type: `CHANNEL_UPDATE`,
            });

            const updateLog = fetchedLogs.entries.first();
            if (!updateLog) return;
            const { executor } = updateLog;
            if (executor.id === client.user.id)
                return;

            // Get new slow mode time
            let newSlowMode = newChannel.rateLimitPerUser;
            let timeString = ``;
            // if newSlowMode is above 60, convert to minutes
            if (newSlowMode > 60)
            {
                newSlowMode = Math.floor(newSlowMode / 60);
                timeString = `${ newSlowMode } ${ global.locale[global.findLocale(oldChannel.guild.id)].minutes }`;
                if (newSlowMode > 60)
                {
                    newSlowMode = Math.floor(newSlowMode / 60);
                    timeString = `${ newSlowMode } ${ global.locale[global.findLocale(oldChannel.guild.id)].hours }`;
                }
            }
            else
                timeString = `${ newSlowMode } ${ global.locale[global.findLocale(oldChannel.guild.id)].seconds }`;

            if (newChannel.rateLimitPerUser === 0)
            {
                if (!auditChannelID || auditChannelID.length < 10) return;
                const auditChannel = client.channels.cache.get(auditChannelID);
                if (!auditChannel) // auditChannelID is invalid.
                    return;
                const embed = new Discord.EmbedBuilder()
                    .setColor(`#00FF00`)
                    .setTimestamp()
                    .setAuthor({ name: `⏲️ (${ global.locale[global.findLocale(oldChannel.guild.id)].slowModeRemoval })` })
                    .addFields([{ name: `${ global.locale[global.findLocale(oldChannel.guild.id)].moderator }`, value: `<@!${ executor.id }>`, inline: true }])
                    .addFields([{ name: `${ global.locale[global.findLocale(oldChannel.guild.id)].channel }`, value: `<#${ newChannel.id }>`, inline: true }])
                    .addFields([{ name: `${ global.locale[global.findLocale(oldChannel.guild.id)].reason }`, value: `${ global.locale[global.findLocale(oldChannel.guild.id)].manuallyRemovedSlowMode }`, inline: true }]);
                auditChannel.send({ embeds: [embed] });
            }
            else
            {
                if (!auditChannelID || auditChannelID.length < 10) return;
                const auditChannel = client.channels.cache.get(auditChannelID);
                if (!auditChannel) // auditChannelID is invalid.
                    return;
                const embed = new Discord.EmbedBuilder()
                    .setColor(`#ff1e00`)
                    .setTimestamp()
                    .setAuthor({ name: `⏲️ (${ global.locale[global.findLocale(oldChannel.guild.id)].slowMode })` })
                    .addFields([{ name: `${ global.locale[global.findLocale(oldChannel.guild.id)].moderator }`, value: `<@!${ executor.id }>`, inline: true }])
                    .addFields([{ name: `${ global.locale[global.findLocale(oldChannel.guild.id)].channel }`, value: `<#${ newChannel.id }>`, inline: true }])
                    .addFields([{ name: `${ global.locale[global.findLocale(oldChannel.guild.id)].time }`, value: `${ timeString }`, inline: true }])
                    .addFields([{ name: `${ global.locale[global.findLocale(oldChannel.guild.id)].reason }`, value: `${ global.locale[global.findLocale(oldChannel.guild.id)].manuallySetSlowMode }`, inline: true }]);
                auditChannel.send({ embeds: [embed] });
            }
        }
    }
};
