import { ChannelType } from "discord.js";
import common from "../utils/common.js";

/**
 * @name messageDelete
 * @description Event that fires when a message is deleted.
 */
export default {
    name: `messageDelete`,
    /**
     * @param {Discord.Message} message The message object.
     * @param {*} Discord The Discord Object.
     * @param {*} client The Client Object.
     */
    async execute(message, Discord, client)
    {
        if (message.author.bot && message.author.id !== client.user.id) return; // ignore other bots
        if (message.channel.type === ChannelType.DM)
            return; // ignore DMs

        const { logSelfDeletes, deletedMessagesChanID } = common.getGuildConfig(message.guild.id);

        // If disabled, do nothing.
        if (!logSelfDeletes)
            return;

        const fetchedLogs = await message.guild.fetchAuditLogs({
            limit: 1,
            type: `MESSAGE_DELETE`,
        });
        const deletionLog = fetchedLogs.entries.first();
        const { target } = deletionLog;
        if (target.id === message.author.id)
            return; // We don't care about moderators deleting stuff.

        const embed = new Discord.EmbedBuilder()
            .setColor(`#ff1e00`)
            .setTimestamp()
            .setAuthor({ name: `🗑️ (${ global.locale[global.findLocale(message.guild.id)].selfDeleted })` })
            .addFields([{ name: `${ global.locale[global.findLocale(message.guild.id)].user }`, value: ` <@!${ message.member.id }> (${ message.member.user.username })`, inline: true }])
            .addFields([{ name: `${ global.locale[global.findLocale(message.guild.id)].channel }`, value: ` <#${ message.channel.id }>`, inline: true }])
            .addFields([{ name: `${ global.locale[global.findLocale(message.guild.id)].content }`, value: common.truncateString(message.content, 1024), inline: false }]);

        const delMessageChan = client.channels.cache.get(deletedMessagesChanID);
        if (delMessageChan)
            delMessageChan.send({ embeds: [embed] });
    }
};
