import { ButtonStyle } from "discord.js";
import SQLite from "better-sqlite3";
import common from "./common.js";

import forcejoin from "../commands/chat_commands/utility/forcejoin.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    accept,
    reject
};

/**
 * @param {*} interaction The interaction object.
 * @param {string} threadId The thread ID.
 * @param {string} reason The reason.
 * @param {*} Discord The Discord Object.
 * @param {*} client The Discord Client Object.
 */
export async function accept(interaction, threadId, reason, Discord, client)
{
    const guildId = interaction.guild.id;
    const { banAppealsChannelID } = common.getGuildConfig(guildId);
    let refreshToken = sql.prepare(`SELECT token FROM banAppealTokens WHERE guildId = ? AND threadId = ?`).get(guildId, threadId);
    refreshToken = refreshToken ? refreshToken.token : undefined;
    let userId = sql.prepare(`SELECT userId FROM banAppealTokens WHERE guildId = ? AND threadId = ?`).get(guildId, threadId);
    userId = userId ? userId.userId : undefined;

    const unbanReason = `${ global.locale[global.findLocale(interaction.guild.id)].appealAccepted } ${ interaction.user.tag } | ${ reason }`;
    const successForceJoin = await forcejoin.forceJoinUser(interaction, userId, refreshToken, unbanReason, Discord, client);
    if (!successForceJoin.success)
    {
        await interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].somethingWentWrong } ${ successForceJoin.error }`);
        return;
    }

    const banAppealsChannel = client.channels.cache.get(banAppealsChannelID);
    banAppealsChannel.messages.fetch(threadId)
        .then((message) => message.react(`✅`));

    await sql.prepare(`DELETE FROM banAppealTokens WHERE guildId = ? AND threadId = ?`).run(guildId, threadId);

    // archive thread and send accept msg
    const thread = await client.channels.cache.get(threadId);
    await thread.send(`${ global.locale[global.findLocale(interaction.guild.id)].appealAccepted } <@!${ interaction.user.id }> ${ global.locale[global.findLocale(interaction.guild.id)].withTheReason } \`${ reason }\`\n${ global.locale[global.findLocale(interaction.guild.id)].banAppealThreadSuccess }`);
    await thread.setArchived(true);

    await interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);

    const originalMessageObject = await banAppealsChannel.messages.fetch(threadId);
    await disableButtons(originalMessageObject, true, true, Discord);
}

/**
 * @param {*} interaction The interaction or message object.
 * @param {string} threadId The thread ID.
 * @param {string} reason The reason.
 * @param {*} Discord The Discord Object.
 * @param {*} client The Discord Client Object.
 */
export async function reject(interaction, threadId, reason, Discord, client)
{
    const { banAppealsChannelID } = common.getGuildConfig(interaction.guild.id);

    const banAppealsChannel = client.channels.cache.get(banAppealsChannelID);
    banAppealsChannel.messages.fetch(threadId)
        .then((message) => message.react(`❌`));
    const thread = await client.channels.cache.get(threadId);
    await thread.send(`${ global.locale[global.findLocale(interaction.guild.id)].appealRejected } <@!${ interaction.user.id }> ${ global.locale[global.findLocale(interaction.guild.id)].withTheReason } \`${ reason }\`\n${ global.locale[global.findLocale(interaction.guild.id)].threadWillBeArchived }`);
    await thread.setArchived(true);
    await interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].interactionBasicSuccess }`);
    const originalMessageObject = await banAppealsChannel.messages.fetch(threadId);
    await disableButtons(originalMessageObject, false, true, Discord);
}

/**
 * @param {object} originalMessageObject The original message object.
 * @param {boolean} disableAccept Whether or not to disable the accept button.
 * @param {boolean} disableReject Whether or not to disable the reject button.
 * @param {*} Discord The Discord Object.
 */
async function disableButtons(originalMessageObject, disableAccept, disableReject, Discord)
{
    const button = new Discord.ButtonBuilder()
        .setCustomId(`accept`)
        .setLabel(`${ global.locale[global.findLocale(originalMessageObject.guild.id)].accept }`)
        .setStyle(ButtonStyle.Success)
        .setDisabled(disableAccept);
    const button2 = new Discord.ButtonBuilder()
        .setCustomId(`reject`)
        .setLabel(`${ global.locale[global.findLocale(originalMessageObject.guild.id)].reject }`)
        .setStyle(ButtonStyle.Danger)
        .setDisabled(disableReject);
    const buttons = [button, button2];
    const row = new Discord.ActionRowBuilder()
        .addComponents(buttons);
    originalMessageObject.edit({ components: [row] });
}
