import SQLite from "better-sqlite3";
import { ButtonStyle } from "discord.js";

const sql = new SQLite(`./src/db.sqlite`);

export default {
    /**
     * @param {Discord.Interaction} interaction The interaction object.
     */
    async giveawayEntry(interaction)
    {
        await interaction.deferReply({ ephemeral: true });
        const userId = interaction.user.id;
        const messageId = interaction.message.id;
        const guildId = interaction.guild.id;
        // Check if giveaway exists
        const exists = await sql.prepare(`SELECT * FROM giveaways WHERE messageId = ?`).get(messageId);
        if (!exists)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].giveawayEnded }`);

        const inDatabase = await sql.prepare(`SELECT * FROM giveawayEntries WHERE userId = ? AND guildId = ? AND messageId = ?`).get(userId, guildId, messageId);
        if (inDatabase)
            return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].giveawayAlreadyEntered }`);
        sql.prepare(`INSERT INTO giveawayEntries (userId, guildId, messageId) VALUES (?, ?, ?)`).run(userId, guildId, messageId);
        interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].giveawayEntered }`);
    },

    /**
     * @param {string} giveawayId The ID of the giveaway.
     * @param {*} client The Discord client.
     * @param {Discord} Discord The Discord object.
     */
    async checkActiveGiveaway(giveawayId, client, Discord)
    {
        const giveawayMeta = await sql.prepare(`SELECT * FROM giveaways WHERE messageId = ${ giveawayId }`).raw().all().flat();
        const guildId = giveawayMeta[0];
        const messageId = giveawayMeta[1];
        const time = giveawayMeta[2];
        const amountOfWinners = giveawayMeta[3];
        const channelId = giveawayMeta[4];

        if (Date.now() >= time)
        {
            const giveawayEntries = await sql.prepare(`SELECT userId FROM giveawayEntries WHERE messageId = ${ giveawayId }`).raw().all().flat();
            const winners = [];
            for (let index = 0; index < amountOfWinners; index++)
            {
                const winner = giveawayEntries[Math.floor(Math.random() * giveawayEntries.length)];
                if (winner !== undefined)
                {
                    winners.push(`<@!${ winner }>`);
                    giveawayEntries.splice(giveawayEntries.indexOf(winner), 1);
                }
            }
            let message;
            message = `**${ global.locale[global.findLocale(guildId)].giveawayDone }**\n\n`;
            message += `${ global.locale[global.findLocale(guildId)].giveawayCongrats }\n\n`;
            message += `||${ winners.join(`, `) }||`;

            const channel = await client.channels.fetch(channelId);
            if (winners.length > 0)
                await channel.send({ content: message });

            // Fetch original message and disable button
            const originalMessage = await channel.messages.fetch(messageId);
            const button = new Discord.ButtonBuilder()
                .setCustomId(`entergiveaway`)
                .setLabel(`${ global.locale[global.findLocale(guildId)].giveawayEnter }`)
                .setStyle(ButtonStyle.Success)
                .setDisabled(true);
            const buttonArray = [button];
            const row = new Discord.ActionRowBuilder()
                .addComponents(buttonArray);
            originalMessage.edit({ components: [row] });

            sql.prepare(`DELETE FROM giveaways WHERE messageId = ?`).run(messageId);
            // await sql.prepare(`DELETE FROM giveawayEntries WHERE messageId = ?`).run(messageId); // Keep these for rerolls?
        }
    }
};

