import chalk from "chalk";

import { createRequire } from "node:module";

const require = createRequire(import.meta.url);

export default {
    log(message)
    {
        logType(message);
    },

    warn(message)
    {
        logType(message, REASON.YELLOW);
    },

    error(message, exit = false, debug = false)
    {
        logType(message, REASON.RED, debug);

        if (exit)
            process.exit(1);
    }
};

const REASON = {
    YELLOW: 0,
    RED: 1,
};

/**
 *
 * @param {string} message The message to log
 * @param {REASON} type Determines type of console output (resolves to int)
 * @param {boolean} debug Whether or not to force a message to show if debug mode is off
 */
function logType(message, type, debug = false)
{
    const { debugMode } = require(`../config.json`);
    if (!debugMode && !debug)
        return;

    switch (type)
    {
        case REASON.YELLOW: {
            console.warn(chalk.yellowBright(message));
            return;
        }
        case REASON.RED: {
            console.error(chalk.redBright(message));
            console.trace(); // log the stack trace
            return;
        }
        default: {
            // eslint-disable-next-line no-restricted-syntax
            console.log(chalk.greenBright(message));
        }
    }
}
