export default {
    handleButtonRole
};

/**
 * @param {*} interaction The interaction object.
 */
export async function handleButtonRole(interaction)
{
    await interaction.deferReply({ ephemeral: true });
    const userId = interaction.user.id;
    const roleIds = interaction.values;
    const user = interaction.guild.members.cache.get(userId);
    const arrayOfObjects = interaction.message.components[0].components[0].options;
    const map = new Map(arrayOfObjects.map((x) => [x.value]));
    const rolesInDropdown = [...map.keys()];

    if (roleIds.length === 0)
    { // They unselected all roles, so remove all roles.
        const removed = [];
        for (const role of rolesInDropdown)
        {
            if (user.roles.cache.has(role))
            {
                await user.roles.remove(role);
                removed.push(`<@&${ role }>`);
            }
        }
        return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].removedRoles } ${ removed.join(`, `) }`);
    }

    const maxValues = interaction.message.components[0].components[0].maxValues;
    if (maxValues === 1)
    { // They can only select one role, so remove all roles except the one they added.
        const added = [roleIds[0]];
        const removed = [];
        for (const role of rolesInDropdown)
        {
            if (role !== roleIds[0] && user.roles.cache.has(role))
            {
                await user.roles.remove(role);
                removed.push(role);
            }
            else if (role === roleIds[0] && !user.roles.cache.has(role))
                await user.roles.add(role);
        }
        return interaction.followUp(`${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].addedRoles } <@&${ added[0] }>`);
    }

    const added = [];
    const removed = [];
    for (const roleId of roleIds)
    {
        if (!user.roles.cache.has(roleId))
        { // If they don't have the role, add it.
            user.roles.add(roleId);
        }
        added.push(`<@&${ roleId }>`);
    }
    for (const role of rolesInDropdown)
    {
        // if its not in added, push to removed & remove it
        if (!added.includes(`<@&${ role }>`) && user.roles.cache.has(role))
        {
            await user.roles.remove(role);
            removed.push(`<@&${ role }>`);
        }
    }
    let message = ``;
    if (added.length > 0)
        message += `${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].addedRoles } ${ added.join(`, `) }\n`;
    if (removed.length > 0)
        message += `${ global.locale[global.findLocale(interaction.guild.id, interaction.locale)].removedRoles } ${ removed.join(`, `) }`;
    return interaction.followUp(message);
}
