import { fileURLToPath } from "node:url";
import fs from "node:fs";

const dirname = fileURLToPath(new URL(`.`, import.meta.url));

/**
 * This makes me want to throw up, but dbd-dashboard wants the raw text to render...
 *
 * @returns {string} The page with JS & CSS.
 */
export default function epochRender()
{
    var index = fs.readFileSync(`${ dirname }/index.html`, `utf8`);
    var css = fs.readFileSync(`${ dirname }/style.css`, `utf8`);
    var js = fs.readFileSync(`${ dirname }/script.js`, `utf8`);

    let locale = `
    switch (navigator.language.split(\`-\`)[0])
    {
        // dynamically load locale
        default:
            break;
    }
    `;

    const guildLanguages = [];
    const locales = fs.readdirSync(`./locale`).filter((file) => file.endsWith(`.json`));
    for (const locale of locales)
    {
        const localeName = locale.split(`.`)[0];
        guildLanguages.push(localeName);
    }

    const switchStatements = [];

    // load every locale file's strings here
    for (const locale of guildLanguages)
    {
        const switchStatement = `
        case \`${ locale }\`:
            document.querySelector(\`#epochTimeGenerator\`).innerHTML = \`${ global.locale[locale].epochTimeGenerator }\`;
            document.querySelector(\`#localDate\`).innerHTML = \`${ global.locale[locale].localDate }: \${ datepicker } \`;
            document.querySelector(\`#localTime\`).innerHTML = \`${ global.locale[locale].localTime }: \${ timepicker } \`;
            document.querySelector(\`#discordTimestamps\`).innerHTML = \`${ global.locale[locale].discordTimestamps }\`;
            document.querySelector(\`#epochTime\`).innerHTML = \`${ global.locale[locale].epochTime }\`;
            break;
        `;
        switchStatements.push(switchStatement);
    }

    const dynamicLocale = `${ switchStatements.join(`\n`) }`;

    locale = locale.replace(`// dynamically load locale`, `${ dynamicLocale }`);

    js = js.replace(`// load locale here`, `${ locale }`);

    index = index.replace(`<!-- load our stylesheet here via replacing -->`, `<style>\n${ css }\n</style>`);
    index = index.replace(`<!-- load our javascript here via replacing -->`, `<script>\n${ js }\n</script>`);

    return index;
}
